package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0`````````````"`!8````!`$`DH````#0``.4````````T`"``
M"``H`!L`&@````8````T`$``-`!``#0```$````!``````4````$`````P``
M`30`0`$T`$`!-`````T````-````!`````$````!``````!`````0`````#=
M@```W8`````%```0``````$``.```$#@``!`X`````)L```2J`````8``!``
M`````@``X!0`0.`4`$#@%````/@```#X````!@````0````$```!1`!``40`
M0`%$````(````"`````$````!&1TY5```->(`$#7B`!`UX@```$4```!%```
M``0````$9'3E40``````````````````````````````!@````0O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````"````!@````@```!A
M````<0```"8``````````````"L`````````2P```&8``````````````"$`
M``!:````30```!\````%````5``````````R````6P```&X````+````*```
M`!<```!J````2@``````````````#@```$(```!G`````````"4````0````
M`P```#D````"`````````&@````V````5P```$D`````````9`````````!?
M`````````!D````,```````````````T````70````````!>````````````
M``!``````0````H```!M``````````````!%`````````!8`````````````
M`"(`````````7````"D````/````!@```"0````M```````````````O````
M8````#<```!.````1@```#T```!I`````````%4````````````````````Q
M````"``````````>````40```",````L````80``````````````````````
M```S```````````````[`````````#H`````````'``````````X````````
M````````````````````````````6```````````````60```#4`````````
M`````````````````````&L```````````````````!'```````````````2
M```````````````\`````````$P`````````#0```%(`````````4P``````
M```````````````````5```````````````N````;````!0```!0````````
M`````````````````$$`````````$0`````````3````8@`````````;````
M5@``````````````"0````0`````````,````"`````8````1````$\`````
M``````````<`````````;P```$,`````````````````````````````````
M````````<````&,````:````)P`````````J`````````#X```!(````'0``
M```````_````````````````````90```````````````````&$````#````
M(`````H``!*@H1%&`@@``(`8$0!6/``(PA%5``T"$``````H```````@(E@`
M``H$"J`'A$1@10A``80`29<\0CX(``$`)(!0(8$,8`A:0$!X0`!`(@(``0``
M0``9`(3`C!"0$`((``B(B9`0`4'"0$"80"R`(`!```D$(,#D`92`P%:7C@``
M``,`````````!`````4````'````"`````````````````````D````+````
M#0````X`````````#P```!$````5`````````!8``````````````!<````:
M````'````"`````A````(@``````````````)````"8````I`````````"H`
M```K````+````"T````N`````````"\`````````,P```#0`````````-P``
M````````````.````#D````Z`````````#L````\````/@```$$```!$````
M`````$<```!(````20```$H```````````````````!,````````````````
M`````````$X```!/`````````%$`````````4@```%0`````````50```%8`
M````````5P```%@```!<`````````%X`````````8`````````!C````9```
M``````!F````9P```&D```!J````:P```&X<DY9?D.]:H_^'CL(<D]M7"Y<Z
M#3HS[$>$!%'2#8)T@6M*\'K%CD%]KPP_S2#.(_<"L'0@?-1DU2AW4N!FS*]F
M]CU.+EX`]]O_AZ0'YYU(L0H"I^#_KDK.+4?>SP'&1^*O#$`Y/>`.QL6%<VP"
MD#_L?)9^/]Y.;S60!8G%(DE)9A+OF&$<D[N<9(6`MV=HDJ"!G/F&[-5%0P\[
MFEM\G4U!A#"$<=;K52UKH]VGKV4`HY[B%`P9]@*BGN/-VH6E,@5@;*'[[=MB
M,@[OT^H.\8VYPL/[Z1R3WNW`XTNM'%AQV2+AT"MSL0XLO=:?&UG)%F`?0#M8
M+#_EPVC4(IA\DN.Z#N3_(?II>F["W9B*5S79BV($K9/!\.,WR._R0T\@A=X8
M?.B;%2+KWLEH6D]`G+G%#8*X,%]]&U%OBP&S<.-O=GU+T+W60PEKD`>I4U$0
M`AVEM0\+FYRI?H+ZT&*+]BSL?)I_:WR6\(;\+)_1^5$+[AW3V_.B,/_F#8)U
MD!!+9D-@=E]?\5KJ%@TYK3VH#?PI').;IDG[X*-26I)7#^_2_4C^WRP?W\5N
MZ1"0?;:;Q2YQLM7(G\JKWP`````````````````````````1```````````@
M````````(```````````(````````^\`0"/`````(A(```````+X`$`<H```
M`(`2```````#<@!`&R`````X$@```````Y4`0"$````!5A(```````3Y`$#B
M4``````@```7```%10!`XF0````$$0``%P```GH`0!N````%K!(```````-K
M`$`BH````!P2```````":@!`'P````<^$@``````!1P`0&QT````@!(```T`
M``,]`$`BP````402```````#5@!`(``````L$@``````!!(`0!P`````U!(`
M``````1[`$!L]```!G02```-````L0!`&P`````&$@``````!+4`0#'8```!
MZ!(```T```/V`$`=8````<@2```````#10!`(*````!<$@```````[\`0"!@
M````!!(```````%0`$`B@````)P2```````$GP!`++P```$\$@``#0``!-,`
M0"`@```!B!(```````54`$!<N```"D02```-```$7@!`,50```"$$@``#0``
M`TX`0!Q@````I!(```````-C`$`;P````O02```````$'`!`'D````#4$@``
M`````D,`0",@```"H!(```````,P`$`D`````1`2```````!@`!`'$`````&
M$@``````!`D`0.)P````!"$``!@```.Q`$`>X````%`2```````"\0!`(N``
M``#<$@```````X<`0!_@````D!(```````4X`$!F_````;`2```-```!C0!`
M&^`````&$@```````*``0!\@````:!(```````0U`$#B;``````0`/_Q```"
MZP!`(,`````X$@```````P``0!V@````.!(```````$=`$`C``````82````
M```!_@!`(D`````&$@``````!`H`0.)P````!"$``!@```#L`$`AH`````82
M```````$:P!`>&0````"$@``#0```AP`0!T`````2!(```````4,`$!X:```
M`'@2```-```"3@!`(.```!`:$@``````!6$`0%M,```!;!(```T```3]`$`D
MH``````2```-```$=0!`>9``````$@``#@``!08`0!J$`````!(```L```#7
M`$`B(````'`2```````#@`!`(8````"L$@```````P\`0'G(````!!$```\`
M``0\`$#B;``````0`/_Q```#U@!`'X````$@$@```````#0`0![`````M!(`
M``````/@`$`B`````7P2```````$Z`!`XF@````$$0``%P```5T`0!]````!
MCA(```````4$`$`EA````&02```-```!H0!`&V````!`$@``````!$@`0/*H
M`````!``__$```5S`$`N'````S@2```-```#'@!`'(````%8$@```````/T`
M0!S@```#E!(```````!X`$`D8````(@2```````"UP!`'8````"@$@``````
M`EP`0""````"Y!(```````$+`$`D@```"`82```````!00!`($````%<$@``
M`````&,`0".@````!A(```````'J`$`=X````"02````````0@!`(<`````&
M$@``````!`@`0.)P````!!$``!@```..`$`=(````!P2```````!R@!`'4``
M``%:$@``````!)$`0#6H````H!(```T```.I`$`>H````)P2````````R`!`
M'V````7:$@``````!/<`0.)0`````!```!<```%N`$`<(`````82````````
MCP!`(^`````&$@```````S4`0"0@````6!(```````3!`$!:Z````&02```-
M```"F`!`'<````(8$@```````H4`0")@````=!(```````0#`$!S^```!"@2
M```-```!I@!`'@````$L$@```````\\`0!_````$?!(```````/&`$`AX```
M`"P2```````"HP!`XG@````3$0``&```!4H`0'S0``!:N!$```\```.B`$`?
MH````%@2```````#G`!`(6`````L$@```````2\`0!Z`````!A(```````/H
M`$`>8````"P2```````"D0!`(2````'\$@```````=@`0".`````)!(`````
M``-Y`$`C8````)@2```````%@`!`,\````'H$@``#0```:L`0"%`````Y!(`
M``````-=`$`;0````"P2```````"+`!`',````00$@``````!-P`0&BL````
MN!(```T```!4`$`C0````)`2```````$30!`+?@````D$@``#0```;<`0!N@
M````:!(```````(U`$`>(````QP2`````&QI8G!E<FPN<V\N-2XQ,`!?7V=M
M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`
M4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F
M;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?
M<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P
M97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP87)S
M97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])
M=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S=E]S971P=FX`
M4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]):6Y?979A;%]P
M='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P='(`<&5R;%]F<F5E
M`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V
M`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M<%]P='(`4&5R;%])
M<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E
M<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN
M<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`'!T:')E861?9V5T<W!E
M8VEF:6,`8VQO<V4`;W!E;C8T`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7TE/
M7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S<')I;G1F`'-T
M<FYC;7``8VQO<V5D:7(`<W1R;F-P>0!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M
M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S
M='(`<FUD:7(`;65M8W!Y`&]P96YD:7(`7U]C='EP95]B7VQO8P!G971U:60`
M<F5A9&QI;FL`97AE8W9P`')E861D:7(V-`!M96UM;W9E`&%C8V5S<P!S=')C
M;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?>'-T870V-`!?7VQX
M<W1A=#8T`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`
M<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F:6YI
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8VQE86YU<`!S:7IE7VQO861?;65?,@!?7V1A=&%?<W1A
M<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`6%-?26YT97)N86QS7U!!4E]#
M3$5!4E-404-+`'!A<E]R;71M<&1I<@!N86UE7VQO861?;65?,@!P87)?;6MT
M;7!D:7(`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C``1TQ)0D-?,BXR`$=,24)#7S(N-`!'3$E"0U\R+C,`
M1TQ)0D-?,BXS+C(````````````"``4``@`"``$``0````(````!``(``@`#
M``$````!``(``@`"`````0`"``$``0`"``(``P````(````"``<`!0`"``$`
M``````$`!@`&```````"`````0````$````!``$``0`!`````@`!``$``P``
M``(``0````$````!``$`!```````!@`````````````````"``(````!``(`
M```!```````(``$```````$``@`"``(````!``(``@````(``@````(``0``
M``(````!`````0```````0`"```"QP```!`````P#6EI$`````8```6-````
M$`UI:1(````%```%EP```````0`%```#!0```!``````#6EI%`````@```6A
M````$`UI:1,````'```%JP```!`):1ER````!```!;4````0#6EI$@````,`
M``67````$`UI:1`````"```%C0``````0.),```!"@``````0.)P``!."0``
M````0.)X``!?"0``````0.$8```1"P``````0.$<```%"P``````0.$@``!J
M"P``````0.$D``!!"P``````0.$H```)"P``````0.$L``!O"P``````0.$P
M```<"P``````0.$T```F"P``````0.$X```/"P``````0.$\``!5"P``````
M0.%````@"P``````0.%$```;"P``````0.%(``!$"P``````0.%,```$"P``
M````0.%0``!K"P``````0.%4``!%"P``````0.%8```P"P``````0.%<``!/
M"P``````0.%@``!0"P``````0.%D```3"P``````0.%H``!'"P``````0.%L
M```J"P``````0.%P``!9"P``````0.%T``!,"P``````0.%X``!<"P``````
M0.%\``!P"P``````0.&````="P``````0.&$``!D"P``````0.&(``!C"P``
M````0.&,``!2"P``````0.&0```\"P``````0.&4```B"P``````0.&8```+
M"P``````0.&<```G"P``````0.&@```_"P``````0.&D``!3"P``````0.&H
M```["P``````0.&L``!A"P``````0.&P``!="P``````0.&T```D"P``````
M0.&X```."P``````0.&\```8"P``````0.'```!*"P``````0.'$```5"P``
M````0.'(``!("P``````0.',```4"P``````0.'0```I"P``````0.'4```R
M"P``````0.'8```&"P``````0.'<``!E"P``````0.'@``!I"P``````0.'D
M``!B"P``````0.'H```X"P``````0.'L```N"P``````0.'P``!-"P``````
M0.'T``!>"P``````0.'X```]"P``````0.'\```W"P``````0.(````L"P``
M````0.($``!:"P``````0.((```6"P``````0.(,```*"P``````0.(0```-
M"P``````0.(4```C"P``````0.(8```K"P``````0.(<```>"P``````0.(@
M``!M"P``````0.(D``!G"P``````0.(H``!F"P``````0.(L``!+"P``````
M0.(P```#"P``````0.(T``!6"P``````0.(X```?"P``````0.(\``!7"P``
M````0.)````V"P``````0.)$``!&"P``````0.)(``!)"P````"0;_`8I]4`
M!@```4```,:`&!^G^O^@4!#P`%C`T`0:S5@0T`!8$<``$A&GA``##>&G)0`$
M```*I%@P(`!-XR``IR4`!```7H!8,"``3>,@`%A`\)B8;_!X!_0'!U`0\!P-
M$%@0$!+2`_`8$`18$!`(!_$```!`X0P`````#1!8$!`66!`0``?Q#1!8$!`.
MI_3_YP```$#A&``````-$%@0$!98$!``!_$-$%@0$`ZG]/_7````0.$<````
M#`T06!`0%E@0$``'\0T06!`0#J?T_\<```!`X2`````8#1!8$!`66!`0``?Q
M#1!8$!`.I_3_MP```$#A)````"0-$%@0$!98$!``!_$-$%@0$`ZG]/^G````
M0.$H````,`T06!`0%E@0$``'\0T06!`0#J?T_Y<```!`X2P````\#1!8$!`6
M6!`0``?Q#1!8$!`.I_3_AP```$#A,````$@-$%@0$!98$!``!_$-$%@0$`ZG
M]/]W````0.$T````5`T06!`0%E@0$``'\0T06!`0#J?T_V<```!`X3@```!@
M#1!8$!`66!`0``?Q#1!8$!`.I_3_5P```$#A/````&P-$%@0$!98$!``!_$-
M$%@0$`ZG]/]'````0.%`````>`T06!`0%E@0$``'\0T06!`0#J?T_S<```!`
MX40```"$#1!8$!`66!`0``?Q#1!8$!`.I_3_)P```$#A2````)`-$%@0$!98
M$!``!_$-$%@0$`ZG]/\7````0.%,````G`T06!`0%E@0$``'\0T06!`0#J?T
M_P<```!`X5````"H#1!8$!`66!`0``?Q#1!8$!`.I_3^]P```$#A5````+0-
M$%@0$!98$!``!_$-$%@0$`ZG]/[G````0.%8````P`T06!`0%E@0$``'\0T0
M6!`0#J?T_M<```!`X5P```#,#1!8$!`66!`0``?Q#1!8$!`.I_3^QP```$#A
M8````-@-$%@0$!98$!``!_$-$%@0$`ZG]/ZW````0.%D````Y`T06!`0%E@0
M$``'\0T06!`0#J?T_J<```!`X6@```#P#1!8$!`66!`0``?Q#1!8$!`.I_3^
MEP```$#A;````/P-$%@0$!98$!``!_$-$%@0$`ZG]/Z'````0.%P```!"`T0
M6!`0%E@0$``'\0T06!`0#J?T_G<```!`X70```$4#1!8$!`66!`0``?Q#1!8
M$!`.I_3^9P```$#A>````2`-$%@0$!98$!``!_$-$%@0$`ZG]/Y7````0.%\
M```!+`T06!`0%E@0$``'\0T06!`0#J?T_D<```!`X8````$X#1!8$!`66!`0
M``?Q#1!8$!`.I_3^-P```$#AA````40-$%@0$!98$!``!_$-$%@0$`ZG]/XG
M````0.&(```!4`T06!`0%E@0$``'\0T06!`0#J?T_A<```!`X8P```%<#1!8
M$!`66!`0``?Q#1!8$!`.I_3^!P```$#AD````6@-$%@0$!98$!``!_$-$%@0
M$`ZG]/WW````0.&4```!=`T06!`0%E@0$``'\0T06!`0#J?T_><```!`X9@`
M``&`#1!8$!`66!`0``?Q#1!8$!`.I_3]UP```$#AG````8P-$%@0$!98$!``
M!_$-$%@0$`ZG]/W'````0.&@```!F`T06!`0%E@0$``'\0T06!`0#J?T_;<`
M``!`X:0```&D#1!8$!`66!`0``?Q#1!8$!`.I_3]IP```$#AJ````;`-$%@0
M$!98$!``!_$-$%@0$`ZG]/V7````0.&L```!O`T06!`0%E@0$``'\0T06!`0
M#J?T_8<```!`X;````'(#1!8$!`66!`0``?Q#1!8$!`.I_3]=P```$#AM```
M`=0-$%@0$!98$!``!_$-$%@0$`ZG]/UG````0.&X```!X`T06!`0%E@0$``'
M\0T06!`0#J?T_5<```!`X;P```'L#1!8$!`66!`0``?Q#1!8$!`.I_3]1P``
M`$#AP````?@-$%@0$!98$!``!_$-$%@0$`ZG]/TW````0.'$```"!`T06!`0
M%E@0$``'\0T06!`0#J?T_2<```!`X<@```(0#1!8$!`66!`0``?Q#1!8$!`.
MI_3]%P```$#AS````AP-$%@0$!98$!``!_$-$%@0$`ZG]/T'````0.'0```"
M*`T06!`0%E@0$``'\0T06!`0#J?T_/<```!`X=0```(T#1!8$!`66!`0``?Q
M#1!8$!`.I_3\YP```$#AV````D`-$%@0$!98$!``!_$-$%@0$`ZG]/S7````
M0.'<```"3`T06!`0%E@0$``'\0T06!`0#J?T_,<```!`X>````)8#1!8$!`6
M6!`0``?Q#1!8$!`.I_3\MP```$#AY````F0-$%@0$!98$!``!_$-$%@0$`ZG
M]/RG````0.'H```"<`T06!`0%E@0$``'\0T06!`0#J?T_)<```!`X>P```)\
M#1!8$!`66!`0``?Q#1!8$!`.I_3\AP```$#A\````H@-$%@0$!98$!``!_$-
M$%@0$`ZG]/QW````0.'T```"E`T06!`0%E@0$``'\0T06!`0#J?T_&<```!`
MX?@```*@#1!8$!`66!`0``?Q#1!8$!`.I_3\5P```$#A_````JP-$%@0$!98
M$!``!_$-$%@0$`ZG]/Q'````0.(````"N`T06!`0%E@0$``'\0T06!`0#J?T
M_#<```!`X@0```+$#1!8$!`66!`0``?Q#1!8$!`.I_3\)P```$#B"````M`-
M$%@0$!98$!``!_$-$%@0$`ZG]/P7````0.(,```"W`T06!`0%E@0$``'\0T0
M6!`0#J?T_`<```!`XA````+H#1!8$!`66!`0``?Q#1!8$!`.I_3[]P```$#B
M%````O0-$%@0$!98$!``!_$-$%@0$`ZG]/OG````0.(8```#``T06!`0%E@0
M$``'\0T06!`0#J?T^]<```!`XAP```,,#1!8$!`66!`0``?Q#1!8$!`.I_3[
MQP```$#B(````Q@-$%@0$!98$!``!_$-$%@0$`ZG]/NW````0.(D```#)`T0
M6!`0%E@0$``'\0T06!`0#J?T^Z<```!`XB@```,P#1!8$!`66!`0``?Q#1!8
M$!`.I_3[EP```$#B+````SP-$%@0$!98$!``!_$-$%@0$`ZG]/N'````0.(P
M```#2`T06!`0%E@0$``'\0T06!`0#J?T^W<```!`XC0```-4#1!8$!`66!`0
M``?Q#1!8$!`.I_3[9P```$#B.````V`-$%@0$!98$!``!_$-$%@0$`ZG]/M7
M````0.(\```#;`T06!`0%E@0$``'\0T06!`0#J?T^T<```!`XD````-X#1!8
M$!`66!`0``?Q#1!8$!`.I_3[-P```$#B1````X0-$%@0$!98$!``!_$-$%@0
M$`ZG]/LG````0.)(```#D`W0I]H`.$%`\`18,/``IPC_^!3PI_K_F-<#\`#P
M`)#O\&!!</!@6&#0!%A0T`!8(-`(6!#0#`WA````0'AH`$!X9`!`<_@`0!U@
M!P>0G_`D#="G^O^@6)#09I4`D`"G=``B6+#08EC`T%Y8H-!:&\J*P``"I\K_
M_U@0L``5'*>D`!"G&@`!4!"P`(D0``)8(:``#>)8$+``%1RG1/_TD@&0`%A`
M\)B8G_"$!_0`0.`(`$#@#`!`XI``0.*,#5!8$%`BOR\0`*>$``I8$%`>$A&G
MA``%6"!0(@?Q!_X``````$#@$)"_\"P-T*?Z_Y@8O](#L&306J<H``!8$-!6
M#>$8$E@0$``8(5@0T%(-X1@26##03EA`T$H8(5A0L&18$-!&#>%80+"@F+^P
ME`?T!P<`0",@`$`?``!`>=8`0!V``$`C@`!`><R0O_`L#="G^N^0&+]0,+!D
M4$"P8%@0T288.Z<Z`&P8(:=(#_]8$-$B#>$8$J<H$&Q0$K``IR@0;%@2L``2
M$:?$`!FG*!!L6!*P`*<:__]#$;!L5!#1'A(1IW0`#*<H$&Q8$K``IQK__Z<H
M$&Q0$K``IR@0;%@2L``2$:?$`"^G&!!L6$&P`!@;IQH`;!@AIS@`+U@0T1H-
MX1@2$A&GA``>IR@``%@0T18-X1@26!`0`!@A6!#1$@WA&!*G*!!L6%*P`!A+
MITH`;!@A6#"P9%@0T0X-X:?T`!>G*```6!#1%@WA&!)8$!``&"%8$-$2#>$8
M$A@A6#"P9%A`L&!8$-$*#>&GNA!P6$"P.)B_L"P']`!`'4``0"!``$`=@`!`
M(X``0"*@````_P!`(>``0'GRD+_P+`W0I_K_@!B_4""P9%`PL'Q8$+!D$A&G
MA``)6!#1-E@0$``2$:=T``BG*```4""P:*?T`'C2`[!PL&2G]``(6#"P<*<Z
M``%0,+!P6""P<$,0(`!4$-$R$A&GA``,6#"P<$,0,`!4$-$RIQX`/:=T_^E8
M$+!P6""P9!@Q&S)0,+!L6!#1-M(#L'00`*?T`#U8$+!L6""P>%@PL&0805@0
MT2X-X1@2$A&G=``I6!"P;%H0L'A#$!``5!#1,J<>`#VG=``=6""P=%@0T398
M$!``&#(;,1@3BA```A@A6!"P?%`@$`!8$+!LIQH``5@@L'@:(5`@L&BG]``6
M6#"P=*<Z``10,+!T6!"P=-(#L'@0`%@@L'@2(J=T_[VG.```4#"P:%@0L&@8
M(5A`L+B8O["L!_0`0"+`````_P!`XG"0O_`L#="G^O^0&+]0(+!D&!NG&@!L
M6""P9!@Q6!#0*@WA&!(8(5A`L*B8O["<!_0`0"<8D+_P+`W0I_K_:!B_4""P
MC%`PL'A8(+!X0Q`@`%00TYJG'@`]IW0`"%@PL'BG.@`!4#"P>%@@L'A8$-.6
M#>$8$E`0L)08&Z<:`)!8(+",&#%8$-.2#>$8$E`0L(!8$+"`$A&GA``\6""P
M@%@0TY8-X1@251"PE*=$`+Q8(+!X0Q`@`%@PL(!"$#``6""P@$,0(`!"$+!W
M0Q"P=U00TYH2$:>$``22`;!W0Q"P=U@PL("G.@`!4#"P@%@@L'BG*@`!4""P
M>%00TYH2$:=T_]BG.```4#"P?*?T`4Y8$-..T@.PB!``IQ@``%`0L(2G]``.
M6""PB*<J``10(+"(6#"PA*<Z``%0,+"$6""PB%@0(``2$:=T_^]8$-.*6!`0
M`!(1IX0`(U@0TXY8(!``6!"PA*<:``*)$``"&#%8$-.&#>$8$A@A6!#3CE`@
M$`!8$-..6!`0`!(1IW0`.:<X__]0,+!\I_0!"%@0TXJG*``!4"`0`%@0L(2G
M&@`"B1```A@A6!#3@@WA&!)0$+"(6#"PB!(SIW0`"*<8__]0$+!\I_0`ZE@0
MTXY8,!``6!"PA(D0``)8(+"(&$%8$--^#>%8$-..T@,0`+"(6!#3CE@@$`!8
M$+"$IQH``8D0``(:$J<H``!0(!``6!"PA%`0L)#2`["`L(RG]``(6#"P@*<Z
M``%0,+"`6""P@$,0(`!4$-.:$A&GA``,6#"P@$,0,`!4$-.:IQX`/:=T_^E8
M$-..6"`0`%@0L)")$``"&,(:P5@@L(!8$+",&#(;,1@36A"PE*<:``(8(5@0
MTX(-X1@24!#``%@0P``2$:=T``BG&/__4!"P?*?T`']8$-..6"`0`%@0L)")
M$``"&A+2`["`$`"G]``(6""P@*<J``%0(+"`6!"PC$,0$`!8,+"`0A`P`%@@
ML(!#$"``0A"P;T,0L&]4$-.:$A&GA``$D@&P;T,@L&]8$+",IQH``5`0L(RG
M&``!%Q)4$-.:$A&G=``,6#"P@$,0,`!4$-.:IQX`/:=T_\M8$+"`DCT0`%@@
ML("G*@`!4""P@%@PL'A#$#``6""P@$(0(`!8,+"`0Q`P`$(0L&=#$+!G5!#3
MFA(1IX0`!)(!L&=#$+!G6""P@*<J``%0(+"`6#"P>*<Z``%0,+!X5!#3FA(1
MIW3_V*<8``!0$+!\6!"P?!@A6$"PT)B_L,0']`<'`$`B``!`(2``0!O``$#B
ME`!`XG``0"<8`$`?X````/^0O_`L#="G^O^0&+]0(+!DI_0`)U@0T()8(!``
M6!"P;(D0``(8,AHQ4#"P8%@0L&"G&@`$6!`0`%@@L&!0$"``6#"P8%@0,``2
M$:>$``I8$+!@IQH`!%`0L&"G]/_I&!NG&@!L6""P9!@Q6!#0?@WA&!(2$:=T
M_]!80+"HF+^PG`?T!P<`0"<8`$#B<)"_\"P-T*?ZWX@8OZ<H``"G&"!P4"&P
M`%@0T3(-X1A"&!NG&A!O6##1+EA0T2H8(5@0T28-X1@2IS@@=%`3L`"G*"!T
M6!*P`!(1IZ0`"*<X``!0,+!DI_0`6Q@;IQH0;Q@[ISH`;A@AIT@0`%@0T2(-
MX1@2IR@@=%`2L`"G."!T6!.P`!(1IZ0`"*<8``!0$+!DI_0`/:<H('18$K``
MIQH``1@A6!#1'@WA&!*G."!P4!.P`*<H('!8$K``$A&G=``(IS@``%`PL&2G
M]``AIQ@@=%A!L``8&Z<:`&ZG."!P6".P`!@Q6!#1&@WAIR@@=%@2L`"G."!P
M6A.P`)(`$`"G&"!P6!&P`%`0L&18$+!D&"&GNB!X6$"P.)B_L"P']`!`'Z``
M0"$@`$`AX`!`)"``0'H2`$!Z!@!`&R"0O_`L#="G^O^@&+]8$-`:#>$8$A@A
M6$"PF)B_L(P']`!`++R0;_`8#="G^N^`&+]0(+!L4#"P:%@0TRX8(5@0TRH-
MX1@2IR@0?%`2L`!8$-,F6!`0`%@@L&P8,5@0TR(-X1@2$A&GA``/6!#3'A@A
M6#"P;%@0TQH-X=(#L&2P;*?T`3A8(+!L6!#3%@WA&!*G*!!T4!*P`%@0TQ)8
M$!``6""P:!@Q6!#3#@WA&!*G*!!P4!*P`*?T`0NG*!!P6!*P`$,0$`!4$-,*
M$A&G=``(6"#3!J<8$'!0(;``IR@0?%@2L``2$:>$`"*G&!!\6"&P`*<8$'!8
M,;``6!#3`@WA&!(2$:=T`!-8$-,26!`0`*<H```8,5@0TPX-X1@2IR@0<%`2
ML`"G]`#3IQ@0<%@AL`!8$-,6#>$8$J<H$'A0$K``I_0`%J<H$'A8$K``IQK_
M_Z<H$'A0$K``IR@0>%@2L`"G*!!P6A*P`)(`$`"G*!!X6!*P`*<:__^G*!!P
M6A*P`$,@$`!8$-,F6!`0`$,0$`!4(-,*5!#3"ADAIX3_U:<H$'A8$K``IQH`
M`:<H$'1:$K``IQX/_Z?$``]8$-,>&"%8,+!L6!#3&@WAT@.P9+!LI_0`CU@0
MTR984!``&!NG&@!P6##2_A@AIQ@0<%A!L`!88+!L6!#2^@WAIR@``%@0TO8-
MX1@26!`0`!@A6!#2\@WA&!(8(5@0TNX-X1@R&!NG&@!P&"%8$-+J#>$8$A(1
MIW0`/J<H``!8$-+V#>$8$E@0$``8(5@0TO(-X1@2&"%8$-+N#>$8$E@0$!!4
M$-+F61#2XJ=T`"08&Z<:`'`8(:<X``%8$-+>#>$8$A(1IW0`%U@0TQX8.Z<Z
M`'`8(5@0TQH-X1@;IQH`<!@A6!#2V@WA&!)0$+!DI_0`(U@0TQ)8$!``IR@`
M`!@Q6!#3#@WA&!*G*!!P4!*P`*<H$'!8$K``$A&G=/[R6!#3'A@A6#"P;%@0
MTQH-X=(#L&2P;%@0L&08(:>Z$(!80+`XF&^P&`?T`$`C8`!`'F```(````#P
M``!`>.``0"'``$`=@`!`(X``0"0@`$!Z,`!`(\``0'HN````_P!`(8``0.)<
M`$`?X`!`*(P`0'H@`$`A``!`XE@`0"A8`$!Z%I"_\"P-4*?Z_Y`8OU`@L&32
M`[!HL&32`[!LL&2G]``?6!"P;$,@$`!8$%!Z6!`0`$,0$`!4(%!V5!!0=ADA
MIW0`"%@0L&RG&@`!4!"P:%@0L&RG&@`!4!"P;%@0L&Q#$!``5!!0=A(1IW3_
MW%@0L&@8(5A`L*B8O["<!_0```#_`$#B6)"_\"P-T*?Z_Y`8OU`@L&Q8$+!L
M$A&GA``+6!"P;$,0$`!4$-'>$A&G=``-6!#1VA@A6!#1U@WA&!)0$+!DI_0`
MO5@@L&Q8$-'2#>$8$J<:__]8(+!L&B%0(+!HI_0`"%@PL&BG.O__4#"P:-4#
ML&BP;*?$`!M8$+!H0R`0`%@0T<Y8$!``0Q`0`%0@T=Y4$-'>&2&GA/_FI_0`
M"%@@L&BG*O__4""P:-4#L&BP;*?$`!-8,+!H0R`P`%@0T<Y8$!``0Q`0`%0@
MT=Y4$-'>&2&G=/_FU0.P:+!LIW0`*U@0L&A#(!``6!#1SE@0$`!#$!``5"#1
MWE00T=X9(:=T``U8$-':&"%8$-'6#>$8$E`0L&2G]`!36!#1SE@0$``8(5@0
MT=8-X1@24!"P9*?T`$98(+!HIRK__U`@L&C5`[!HL&RGQ``36#"P:$,@,`!8
M$-'.6!`0`$,0$`!4(-'>5!#1WADAIX3_YE@@L&A8$+!L&#(;,1@3IQH``E40
MT<JGQ``(IQ@``%`0L&2G]``76""P:%@0L&P8,ALQ&!.G&@`!&$%8$-'&&"%8
M,+!L6!#1P@WAT@.P9-'&6!"P9!@A6$"PJ)B_L)P']`!`'&``0.*8```0``!`
MXE@`0!_@`$`C8`!`>BX```#_D+_P+`W0I_K_>!B_6!#1WM(AL&(0`%@0T=H8
M(5@0T=8-X5@0T=(8(5@0T=8-X5@0T<X8(5@0T=8-X5@0T<H8(5@0T=8-X5@0
MT<88(5@0T=8-X5@0T<(8(5@0T=8-X5@0T;X8(5@0T=8-X5@0T;H8(5@0T=8-
MX5@0T;88(5@0T=8-X5@0T;(8(5@0T:X-X1@24!"PA%@0L(02$:>$``I8$-'&
M&"%8,+"$6!#1J@WA6!#1IA@A6!#1K@WA&!)0$+"$6!"PA!(1IX0`"E@0T:(8
M(5@PL(18$-&J#>%8$-&>&"%8$-&N#>$8$E`0L(18$+"$$A&GA``,6!#1SA@A
M6#"PA%@0T:H-X:?T`#E8$-&:&"%8$-&N#>$8$E`0L(18$+"$$A&GA``,6!#1
MRA@A6#"PA%@0T:H-X:?T`"$8&Z<:`&*G&@`14!"PA%@0T998(+"$&#&G2``*
M6!#1D@WA&!(2$:=T``Q8$+"$IQH`"E@@T<H8,5@0T:H-X5@0T=I8,-&.&"%8
M$-&J#>%80+#`F+^PM`?T!P<`0'KF`$`BP`!`>MH`0'K(`$!ZN`!`>JP`0'J:
M`$`HC`!`*%@`0'J(`$!Z?`!`>G(`0'H@`$!Z:`!`>EX`0'I4`$!Z%@!`>D@`
M0"PP`$!Z.`!`>NB0O_`L#="G^O^0&+]8$-"66!`0`*<>__^G=``R6!#0DA@A
M6!#0C@WA&!)0$+!L6!"P;!(1IX0`&U@0L&Q#$!``5!#0BA(1IX0`$E@0L&Q#
M$!``5!#0BJ<>`#"GA``(IQ@``5`0L&2G]``&IQ@``%`0L&18$-"6T@,0`+!D
M6!#0EE@0$``8(5A`L*B8O["<!_0```#_`$`H6`!`>E0`0.)@D+_P+*?5``S*
M8L'6CQN\W&[9ZZ%:@GF9_____Z?Z_C`8OU`@L&18$+!DIQH`'%`0L;"G&```
M4!"QK*?T`"!8$+&PT@.QM!``6!"QL*<:``10$+&P6!"QK*<H\`")$``"03"Q
MT!H36$"QM%!!+IQ8$+&LIQH``5`0L:Q8$+&LIQX`#Z?$_]ZG6``04%"QK*?T
M`&E80+&L6!"QK*<:__VG*/``B1```D$PL=`:$U@Q+IQ8$+&LIQK_^*<H\`")
M$``"05"QT!H56!$NG!<Q6!"QK*<:__*G*/``B1```D%0L=`:%5@1+IP7,5@0
ML:RG&O_PIRCP`(D0``)!4+'0&A58$2Z<%S&G*/``&!2)$``"04"QT!H44#$N
MG%A`L:Q8$+&LIRCP`(D0``)!4+'0&A58$2Z<&#&(,``?&"&)(``!%B.G./``
M&!2)$``"04"QT!H44"$^G%@0L:RG&@`!4!"QK%@0L:RG'@!/I\3_E5@0L&32
M`[&X$`!8$+!DT@.QO!`$6!"P9-(#L<`0"%@0L&32`['$$`Q8$+!DT@.QR!`0
M&!NG&@!L4!"QS%@0L;@8(8@@`!L8,8DP``46,E@@L;Q4(+'`6!"QO%<0T!!4
M$+'$%A(:$Q@A6B"QR%@0L<Q8$!``&A):$-`,4!"QM%@0L<RG&@`$4!"QS%@0
ML;P8(8@@``*)$``>%A)0$+&\6!"QM!@AB"``&Q@QB3``!18R6""QN%0@L;Q8
M$+&X5Q#0$%00L<`6$AH3&"%:(+'$6!"QS%@0$``:$EH0T`Q0$+'(6!"QS*<:
M``10$+',6!"QN!@AB"```HD0`!X6$E`0L;A8$+'(&"&((``;&#&),``%%C)8
M(+&T5""QN%@0L;17$-`05!"QO!82&A,8(5H@L<!8$+',6!`0`!H26A#0#%`0
ML<18$+',IQH`!%`0L<Q8$+&T&"&((``"B1``'A824!"QM%@0L<08(8@@`!L8
M,8DP``46,E@@L<A4(+&T6!"QR%<0T!!4$+&X%A(:$Q@A6B"QO%@0L<Q8$!``
M&A):$-`,4!"QP%@0L<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(6!"Q
MP!@AB"``&Q@QB3``!18R6""QQ%0@L<A8$+'$5Q#0$%00L;06$AH3&"%:(+&X
M6!"QS%@0$``:$EH0T`Q0$+&\6!"QS*<:``10$+',6!"QQ!@AB"```HD0`!X6
M$E`0L<18$+&\&"&((``;&#&),``%%C)8(+'`5""QQ%@0L<!7$-`05!"QR!82
M&A,8(5H@L;18$+',6!`0`!H26A#0#%`0L;A8$+',IQH`!%`0L<Q8$+'`&"&(
M(``"B1``'A824!"QP%@0L;@8(8@@`!L8,8DP``46,E@@L;Q4(+'`6!"QO%<0
MT!!4$+'$%A(:$Q@A6B"QR%@0L<Q8$!``&A):$-`,4!"QM%@0L<RG&@`$4!"Q
MS%@0L;P8(8@@``*)$``>%A)0$+&\6!"QM!@AB"``&Q@QB3``!18R6""QN%0@
ML;Q8$+&X5Q#0$%00L<`6$AH3&"%:(+'$6!"QS%@0$``:$EH0T`Q0$+'(6!"Q
MS*<:``10$+',6!"QN!@AB"```HD0`!X6$E`0L;A8$+'(&"&((``;&#&),``%
M%C)8(+&T5""QN%@0L;17$-`05!"QO!82&A,8(5H@L<!8$+',6!`0`!H26A#0
M#%`0L<18$+',IQH`!%`0L<Q8$+&T&"&((``"B1``'A824!"QM%@0L<08(8@@
M`!L8,8DP``46,E@@L<A4(+&T6!"QR%<0T!!4$+&X%A(:$Q@A6B"QO%@0L<Q8
M$!``&A):$-`,4!"QP%@0L<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(
M6!"QP!@AB"``&Q@QB3``!18R6""QQ%0@L<A8$+'$5Q#0$%00L;06$AH3&"%:
M(+&X6!"QS%@0$``:$EH0T`Q0$+&\6!"QS*<:``10$+',6!"QQ!@AB"```HD0
M`!X6$E`0L<18$+&\&"&((``;&#&),``%%C)8(+'`5""QQ%@0L<!7$-`05!"Q
MR!82&A,8(5H@L;18$+',6!`0`!H26A#0#%`0L;A8$+',IQH`!%`0L<Q8$+'`
M&"&((``"B1``'A824!"QP%@0L;@8(8@@`!L8,8DP``46,E@@L;Q4(+'`6!"Q
MO%<0T!!4$+'$%A(:$Q@A6B"QR%@0L<Q8$!``&A):$-`,4!"QM%@0L<RG&@`$
M4!"QS%@0L;P8(8@@``*)$``>%A)0$+&\6!"QM!@AB"``&Q@QB3``!18R6""Q
MN%0@L;Q8$+&X5Q#0$%00L<`6$AH3&"%:(+'$6!"QS%@0$``:$EH0T`Q0$+'(
M6!"QS*<:``10$+',6!"QN!@AB"```HD0`!X6$E`0L;A8$+'(&"&((``;&#&)
M,``%%C)8(+&T5""QN%@0L;17$-`05!"QO!82&A,8(5H@L<!8$+',6!`0`!H2
M6A#0#%`0L<18$+',IQH`!%`0L<Q8$+&T&"&((``"B1``'A824!"QM%@0L<08
M(8@@`!L8,8DP``46,E@@L<A4(+&T6!"QR%<0T!!4$+&X%A(:$Q@A6B"QO%@0
ML<Q8$!``&A):$-`,4!"QP%@0L<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0
M$+'(6!"QP!@AB"``&Q@QB3``!18R6""QQ%0@L<A8$+'$5Q#0$%00L;06$AH3
M&"%:(+&X6!"QS%@0$``:$EH0T`Q0$+&\6!"QS*<:``10$+',6!"QQ!@AB"``
M`HD0`!X6$E`0L<18$+&\&"&((``;&#&),``%%C)8(+'`5""QQ%@0L<!7$-`0
M5!"QR!82&A,8(5H@L;18$+',6!`0`!H26A#0#%`0L;A8$+',IQH`!%`0L<Q8
M$+'`&"&((``"B1``'A824!"QP%@0L;@8(8@@`!L8,8DP``46,E@@L;Q4(+'`
M6!"QO%<0T!!4$+'$%A(:$Q@A6B"QR%@0L<Q8$!``&A):$-`,4!"QM%@0L<RG
M&@`$4!"QS%@0L;P8(8@@``*)$``>%A)0$+&\6!"QM!@AB"``&Q@QB3``!18R
M6""QN%0@L;Q8$+&X5Q#0$%00L<`6$AH3&"%:(+'$6!"QS%@0$``:$EH0T`Q0
M$+'(6!"QS*<:``10$+',6!"QN!@AB"```HD0`!X6$E`0L;A8$+'(&"&((``;
MB1``!1826""QM%<@L;A7(+&\&A(8(5H@L<!8$+',6!`0`!H26A#0"%`0L<18
M$+',IQH`!%`0L<Q8$+&T&"&((``"B1``'A824!"QM%@0L<08(8@@`!N)$``%
M%A)8(+'(5R"QM%<@L;@:$A@A6B"QO%@0L<Q8$!``&A):$-`(4!"QP%@0L<RG
M&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(6!"QP!@AB"``&XD0``46$E@@
ML<17(+'(5R"QM!H2&"%:(+&X6!"QS%@0$``:$EH0T`A0$+&\6!"QS*<:``10
M$+',6!"QQ!@AB"```HD0`!X6$E`0L<18$+&\&"&((``;B1``!1826""QP%<@
ML<17(+'(&A(8(5H@L;18$+',6!`0`!H26A#0"%`0L;A8$+',IQH`!%`0L<Q8
M$+'`&"&((``"B1``'A824!"QP%@0L;@8(8@@`!N)$``%%A)8(+&\5R"QP%<@
ML<0:$A@A6B"QR%@0L<Q8$!``&A):$-`(4!"QM%@0L<RG&@`$4!"QS%@0L;P8
M(8@@``*)$``>%A)0$+&\6!"QM!@AB"``&XD0``46$E@@L;A7(+&\5R"QP!H2
M&"%:(+'$6!"QS%@0$``:$EH0T`A0$+'(6!"QS*<:``10$+',6!"QN!@AB"``
M`HD0`!X6$E`0L;A8$+'(&"&((``;B1``!1826""QM%<@L;A7(+&\&A(8(5H@
ML<!8$+',6!`0`!H26A#0"%`0L<18$+',IQH`!%`0L<Q8$+&T&"&((``"B1``
M'A824!"QM%@0L<08(8@@`!N)$``%%A)8(+'(5R"QM%<@L;@:$A@A6B"QO%@0
ML<Q8$!``&A):$-`(4!"QP%@0L<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0
M$+'(6!"QP!@AB"``&XD0``46$E@@L<17(+'(5R"QM!H2&"%:(+&X6!"QS%@0
M$``:$EH0T`A0$+&\6!"QS*<:``10$+',6!"QQ!@AB"```HD0`!X6$E`0L<18
M$+&\&"&((``;B1``!1826""QP%<@L<17(+'(&A(8(5H@L;18$+',6!`0`!H2
M6A#0"%`0L;A8$+',IQH`!%`0L<Q8$+'`&"&((``"B1``'A824!"QP%@0L;@8
M(8@@`!N)$``%%A)8(+&\5R"QP%<@L<0:$A@A6B"QR%@0L<Q8$!``&A):$-`(
M4!"QM%@0L<RG&@`$4!"QS%@0L;P8(8@@``*)$``>%A)0$+&\6!"QM!@AB"``
M&XD0``46$E@@L;A7(+&\5R"QP!H2&"%:(+'$6!"QS%@0$``:$EH0T`A0$+'(
M6!"QS*<:``10$+',6!"QN!@AB"```HD0`!X6$E`0L;A8$+'(&"&((``;B1``
M!1826""QM%<@L;A7(+&\&A(8(5H@L<!8$+',6!`0`!H26A#0"%`0L<18$+',
MIQH`!%`0L<Q8$+&T&"&((``"B1``'A824!"QM%@0L<08(8@@`!N)$``%%A)8
M(+'(5R"QM%<@L;@:$A@A6B"QO%@0L<Q8$!``&A):$-`(4!"QP%@0L<RG&@`$
M4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(6!"QP!@AB"``&XD0``46$E@@L<17
M(+'(5R"QM!H2&"%:(+&X6!"QS%@0$``:$EH0T`A0$+&\6!"QS*<:``10$+',
M6!"QQ!@AB"```HD0`!X6$E`0L<18$+&\&"&((``;B1``!1826""QP%<@L<17
M(+'(&A(8(5H@L;18$+',6!`0`!H26A#0"%`0L;A8$+',IQH`!%`0L<Q8$+'`
M&"&((``"B1``'A824!"QP%@0L;@8(8@@`!N)$``%%A)8(+&\5R"QP%<@L<0:
M$A@A6B"QR%@0L<Q8$!``&A):$-`(4!"QM%@0L<RG&@`$4!"QS%@0L;P8(8@@
M``*)$``>%A)0$+&\6!"QM!@AB"``&XD0``46$E@@L;A7(+&\5R"QP!H2&"%:
M(+'$6!"QS%@0$``:$EH0T`A0$+'(6!"QS*<:``10$+',6!"QN!@AB"```HD0
M`!X6$E`0L;A8$+'(&"&((``;B1``!1826""QM%<@L;A7(+&\&A(8(5H@L<!8
M$+',6!`0`!H26A#0"%`0L<18$+',IQH`!%`0L<Q8$+&T&"&((``"B1``'A82
M4!"QM%@0L<08(8@@`!N)$``%%A)8(+'(5R"QM%<@L;@:$A@A6B"QO%@0L<Q8
M$!``&A):$-`(4!"QP%@0L<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(
M6!"QP!@QB#``&Q@AB2``!18C6!"QR%80L;08,50PL<18$+'(5!"QM!83&A(8
M(5H@L;A8$+',6!`0`!H26A#0!%`0L;Q8$+',IQH`!%`0L<Q8$+'$&"&((``"
MB1``'A824!"QQ%@0L;P8,8@P`!L8(8D@``46(U@0L<16$+'(&#%4,+'`6!"Q
MQ%00L<@6$QH2&"%:(+&T6!"QS%@0$``:$EH0T`10$+&X6!"QS*<:``10$+',
M6!"QP!@AB"```HD0`!X6$E`0L<!8$+&X&#&(,``;&"&)(``%%B-8$+'`5A"Q
MQ!@Q5#"QO%@0L<!4$+'$%A,:$A@A6B"QR%@0L<Q8$!``&A):$-`$4!"QM%@0
ML<RG&@`$4!"QS%@0L;P8(8@@``*)$``>%A)0$+&\6!"QM!@QB#``&Q@AB2``
M!18C6!"QO%80L<`8,50PL;A8$+&\5!"QP!83&A(8(5H@L<18$+',6!`0`!H2
M6A#0!%`0L<A8$+',IQH`!%`0L<Q8$+&X&"&((``"B1``'A824!"QN%@0L<@8
M,8@P`!L8(8D@``46(U@0L;A6$+&\&#%4,+&T6!"QN%00L;P6$QH2&"%:(+'`
M6!"QS%@0$``:$EH0T`10$+'$6!"QS*<:``10$+',6!"QM!@AB"```HD0`!X6
M$E`0L;18$+'$&#&(,``;&"&)(``%%B-8$+&T5A"QN!@Q5#"QR%@0L;14$+&X
M%A,:$A@A6B"QO%@0L<Q8$!``&A):$-`$4!"QP%@0L<RG&@`$4!"QS%@0L<@8
M(8@@``*)$``>%A)0$+'(6!"QP!@QB#``&Q@AB2``!18C6!"QR%80L;08,50P
ML<18$+'(5!"QM!83&A(8(5H@L;A8$+',6!`0`!H26A#0!%`0L;Q8$+',IQH`
M!%`0L<Q8$+'$&"&((``"B1``'A824!"QQ%@0L;P8,8@P`!L8(8D@``46(U@0
ML<16$+'(&#%4,+'`6!"QQ%00L<@6$QH2&"%:(+&T6!"QS%@0$``:$EH0T`10
M$+&X6!"QS*<:``10$+',6!"QP!@AB"```HD0`!X6$E`0L<!8$+&X&#&(,``;
M&"&)(``%%B-8$+'`5A"QQ!@Q5#"QO%@0L<!4$+'$%A,:$A@A6B"QR%@0L<Q8
M$!``&A):$-`$4!"QM%@0L<RG&@`$4!"QS%@0L;P8(8@@``*)$``>%A)0$+&\
M6!"QM!@QB#``&Q@AB2``!18C6!"QO%80L<`8,50PL;A8$+&\5!"QP!83&A(8
M(5H@L<18$+',6!`0`!H26A#0!%`0L<A8$+',IQH`!%`0L<Q8$+&X&"&((``"
MB1``'A824!"QN%@0L<@8,8@P`!L8(8D@``46(U@0L;A6$+&\&#%4,+&T6!"Q
MN%00L;P6$QH2&"%:(+'`6!"QS%@0$``:$EH0T`10$+'$6!"QS*<:``10$+',
M6!"QM!@AB"```HD0`!X6$E`0L;18$+'$&#&(,``;&"&)(``%%B-8$+&T5A"Q
MN!@Q5#"QR%@0L;14$+&X%A,:$A@A6B"QO%@0L<Q8$!``&A):$-`$4!"QP%@0
ML<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(6!"QP!@QB#``&Q@AB2``
M!18C6!"QR%80L;08,50PL<18$+'(5!"QM!83&A(8(5H@L;A8$+',6!`0`!H2
M6A#0!%`0L;Q8$+',IQH`!%`0L<Q8$+'$&"&((``"B1``'A824!"QQ%@0L;P8
M,8@P`!L8(8D@``46(U@0L<16$+'(&#%4,+'`6!"QQ%00L<@6$QH2&"%:(+&T
M6!"QS%@0$``:$EH0T`10$+&X6!"QS*<:``10$+',6!"QP!@AB"```HD0`!X6
M$E`0L<!8$+&X&#&(,``;&"&)(``%%B-8$+'`5A"QQ!@Q5#"QO%@0L<!4$+'$
M%A,:$A@A6B"QR%@0L<Q8$!``&A):$-`$4!"QM%@0L<RG&@`$4!"QS%@0L;P8
M(8@@``*)$``>%A)0$+&\6!"QM!@QB#``&Q@AB2``!18C6!"QO%80L<`8,50P
ML;A8$+&\5!"QP!83&A(8(5H@L<18$+',6!`0`!H26A#0!%`0L<A8$+',IQH`
M!%`0L<Q8$+&X&"&((``"B1``'A824!"QN%@0L<@8,8@P`!L8(8D@``46(U@0
ML;A6$+&\&#%4,+&T6!"QN%00L;P6$QH2&"%:(+'`6!"QS%@0$``:$EH0T`10
M$+'$6!"QS*<:``10$+',6!"QM!@AB"```HD0`!X6$E`0L;18$+'$&#&(,``;
M&"&)(``%%B-8$+&T5A"QN!@Q5#"QR%@0L;14$+&X%A,:$A@A6B"QO%@0L<Q8
M$!``&A):$-`$4!"QP%@0L<RG&@`$4!"QS%@0L<@8(8@@``*)$``>%A)0$+'(
M6!"QP!@QB#``&Q@AB2``!18C6!"QR%80L;08,50PL<18$+'(5!"QM!83&A(8
M(5H@L;A8$+',6!`0`!H26A#0!%`0L;Q8$+',IQH`!%`0L<Q8$+'$&"&((``"
MB1``'A824!"QQ%@0L;P8,8@P`!L8(8D@``46(U@0L<16$+'(&#%4,+'`6!"Q
MQ%00L<@6$QH2&"%:(+&T6!"QS%@0$``:$EH0T`10$+&X6!"QS*<:``10$+',
M6!"QP!@AB"```HD0`!X6$E`0L<!8$+&X&"&((``;B1``!1826""QO%<@L<!7
M(+'$&A(8(5H@L<A8$+',6!`0`!H26A#0`%`0L;18$+',IQH`!%`0L<Q8$+&\
M&"&((``"B1``'A824!"QO%@0L;08(8@@`!N)$``%%A)8(+&X5R"QO%<@L<`:
M$A@A6B"QQ%@0L<Q8$!``&A):$-``4!"QR%@0L<RG&@`$4!"QS%@0L;@8(8@@
M``*)$``>%A)0$+&X6!"QR!@AB"``&XD0``46$E@@L;17(+&X5R"QO!H2&"%:
M(+'`6!"QS%@0$``:$EH0T`!0$+'$6!"QS*<:``10$+',6!"QM!@AB"```HD0
M`!X6$E`0L;18$+'$&"&((``;B1``!1826""QR%<@L;17(+&X&A(8(5H@L;Q8
M$+',6!`0`!H26A#0`%`0L<!8$+',IQH`!%`0L<Q8$+'(&"&((``"B1``'A82
M4!"QR%@0L<`8(8@@`!N)$``%%A)8(+'$5R"QR%<@L;0:$A@A6B"QN%@0L<Q8
M$!``&A):$-``4!"QO%@0L<RG&@`$4!"QS%@0L<08(8@@``*)$``>%A)0$+'$
M6!"QO!@AB"``&XD0``46$E@@L<!7(+'$5R"QR!H2&"%:(+&T6!"QS%@0$``:
M$EH0T`!0$+&X6!"QS*<:``10$+',6!"QP!@AB"```HD0`!X6$E`0L<!8$+&X
M&"&((``;B1``!1826""QO%<@L<!7(+'$&A(8(5H@L<A8$+',6!`0`!H26A#0
M`%`0L;18$+',IQH`!%`0L<Q8$+&\&"&((``"B1``'A824!"QO%@0L;08(8@@
M`!N)$``%%A)8(+&X5R"QO%<@L<`:$A@A6B"QQ%@0L<Q8$!``&A):$-``4!"Q
MR%@0L<RG&@`$4!"QS%@0L;@8(8@@``*)$``>%A)0$+&X6!"QR!@AB"``&XD0
M``46$E@@L;17(+&X5R"QO!H2&"%:(+'`6!"QS%@0$``:$EH0T`!0$+'$6!"Q
MS*<:``10$+',6!"QM!@AB"```HD0`!X6$E`0L;18$+'$&"&((``;B1``!182
M6""QR%<@L;17(+&X&A(8(5H@L;Q8$+',6!`0`!H26A#0`%`0L<!8$+',IQH`
M!%`0L<Q8$+'(&"&((``"B1``'A824!"QR%@0L<`8(8@@`!N)$``%%A)8(+'$
M5R"QR%<@L;0:$A@A6B"QN%@0L<Q8$!``&A):$-``4!"QO%@0L<RG&@`$4!"Q
MS%@0L<08(8@@``*)$``>%A)0$+'$6!"QO!@AB"``&XD0``46$E@@L<!7(+'$
M5R"QR!H2&"%:(+&T6!"QS%@0$``:$EH0T`!0$+&X6!"QS*<:``10$+',6!"Q
MP!@AB"```HD0`!X6$E`0L<!8$+&X&"&((``;B1``!1826""QO%<@L<!7(+'$
M&A(8(5H@L<A8$+',6!`0`!H26A#0`%`0L;18$+',IQH`!%`0L<Q8$+&\&"&(
M(``"B1``'A824!"QO%@0L;08(8@@`!N)$``%%A)8(+&X5R"QO%<@L<`:$A@A
M6B"QQ%@0L<Q8$!``&A):$-``4!"QR%@0L<RG&@`$4!"QS%@0L;@8(8@@``*)
M$``>%A)0$+&X6!"QR!@AB"``&XD0``46$E@@L;17(+&X5R"QO!H2&"%:(+'`
M6!"QS%@0$``:$EH0T`!0$+'$6!"QS*<:``10$+',6!"QM!@AB"```HD0`!X6
M$E`0L;18$+'$&"&((``;B1``!1826""QR%<@L;17(+&X&A(8(5H@L;Q8$+',
M6!`0`!H26A#0`%`0L<!8$+',IQH`!%`0L<Q8$+'(&"&((``"B1``'A824!"Q
MR%@0L<`8(8@@`!N)$``%%A)8(+'$5R"QR%<@L;0:$A@A6B"QN%@0L<Q8$!``
M&A):$-``4!"QO%@0L<RG&@`$4!"QS%@0L<08(8@@``*)$``>%A)0$+'$6!"Q
MO!@AB"``&XD0``46$E@@L<!7(+'$5R"QR!H2&"%:(+&T6!"QS%@0$``:$EH0
MT`!0$+&X6!"QS*<:``10$+',6!"QP!@AB"```HD0`!X6$E`0L<!8$+&X&"&(
M(``;B1``!1826""QO%<@L<!7(+'$&A(8(5H@L<A8$+',6!`0`!H26A#0`%`0
ML;18$+',IQH`!%`0L<Q8$+&\&"&((``"B1``'A824!"QO%@0L;08(8@@`!N)
M$``%%A)8(+&X5R"QO%<@L<`:$A@A6B"QQ%@0L<Q8$!``&A):$-``4!"QR%@0
ML<RG&@`$4!"QS%@0L;@8(8@@``*)$``>%A)0$+&X6!"P9%@0$``8(5H@L<A8
M$+!D4"`0`%@0L&18$!`$&"%:(+&T6!"P9%`@$`18$+!D6!`0"!@A6B"QN%@0
ML&10(!`(6!"P9%@0$`P8(5H@L;Q8$+!D4"`0#%@0L&18$!`0&"%:(+'`6!"P
M9%`@$!!80+((F+^Q_`?TD+_P+`U0I_K_F!B_4""P9%@0L&18(%"&4"`0`%@0
ML&18(%""4"`0!%@0L&18(%!^4"`0"%@0L&18(%!Z4"`0#%@0L&18(%!V4"`0
M$%@0L&2G*```4"`0%%@0L&2G*```4"`0&%@0L&2G*```4"`07%A`L*"8O["4
M!_0'!\/2X?`0,E1VF+K<_N_-JXEG12,!D+_P+`W0I_K_B!B_4""P;%`PL&A0
M0+!D6!"P;%@@$!18$+!DB1```QH24!"P=%@0L&Q8$!`451"P=*?$``U8$+!L
M6!`0&!@AIRH``5@0L&Q0(!`86!"P;-(#$!2P=%@0L&Q8(!`86!"P9(@0`!T:
M(5@0L&Q0(!`86!"P;%@0$%P2$:>$`&A8$+!L6"`07*<8`$`;$E`0L'!8$+!P
M61"P9*?$``72`[!PL&18(+!LIRH`'%@0L&Q8$!!<&A)80+!P&"%8,+!H6!#1
MB@WA6!"P9%L0L'!0$+!D6!"P<%H0L&A0$+!H6!"P;%@0$%P8(5H@L'!8$+!L
M4"`07%@0L&Q8$!!<IQX`0*=T`#U8(+!L6!#1A@WAI_0`'U@0L&RG&@`<&"%8
M,+!HIT@`0%@0T8H-X5@0L&BG&@!`4!"P:%@0L&2G&O_`4!"P9%@@L&Q8$-&&
M#>%8$+!DIQX`/Z<D_]]8$+!LIQH`'%A`L&08(5@PL&A8$-&*#>%8$+!LT@,0
M7+!D6$"PL)B_L*0']`<'`$`V2`!`'Z"0O_`L#="G^O^8&+]0(+!D4#"P8%@@
ML&!8$-'N#>%8$+!@6!`0`(@0`!@8(5@0L&1"(!``6""P9*<J``%8$+!@6!`0
M`(@0`!!"$"``6""P9*<J``)8$+!@6!`0`(@0``A"$"``6""P9*<J``-8$+!@
M6!`0`$(0(`!8(+!DIRH`!%@0L&!8$!`$B!``&$(0(`!8(+!DIRH`!5@0L&!8
M$!`$B!``$$(0(`!8(+!DIRH`!E@0L&!8$!`$B!``"$(0(`!8(+!DIRH`!U@0
ML&!8$!`$0A`@`%@@L&2G*@`(6!"P8%@0$`B($``80A`@`%@@L&2G*@`)6!"P
M8%@0$`B($``00A`@`%@@L&2G*@`*6!"P8%@0$`B($``(0A`@`%@@L&2G*@`+
M6!"P8%@0$`A"$"``6""P9*<J``Q8$+!@6!`0#(@0`!A"$"``6""P9*<J``U8
M$+!@6!`0#(@0`!!"$"``6""P9*<J``Y8$+!@6!`0#(@0``A"$"``6""P9*<J
M``]8$+!@6!`0#$(0(`!8(+!DIRH`$%@0L&!8$!`0B!``&$(0(`!8(+!DIRH`
M$5@0L&!8$!`0B!``$$(0(`!8(+!DIRH`$E@0L&!8$!`0B!``"$(0(`!8(+!D
MIRH`$U@0L&!8$!`00A`@`%A`L*"8O["4!_0'!P!`-DB0O_`L#="G^O^(&+]0
M(+!D4#"P8%@0L&#2`[!P$!18$+!@T@.P=!`86!"P<(@0``-4$-%R4!"P;%@@
ML&"G*@`<6!"P;!H2DH`0`%@0L&RG&@`!4!"P;%@0L&RG'@`XI\0`)E@@L&"G
M*@`<6!"P;!HAIQ@`0%L0L&RG.```&$%8$-%N#>%8(+!@6!#1:@WA6!"P8*<:
M`!P8(:<X``"G2``X6!#1;@WAI_0`$U@@L&"G*@`<6!"P;!HAIQ@`.%L0L&RG
M.```&$%8$-%N#>%8$+!TB!``&!@A6!"P8$(@$%18$+!TB!``$!@A6!"P8$(@
M$%58$+!TB!``"!@A6!"P8$(@$%98$+!T&"%8$+!@0B`05U@0L'"($``8&"%8
M$+!@0B`06%@0L'"($``0&"%8$+!@0B`065@0L'"($``(&"%8$+!@0B`06E@0
ML'`8(5@0L&!"(!!;6""P9%@PL&!8$-%F#>%80+"PF+^PI`?T`$!7=`!`-D@`
M0!T@````/Y"_\"P-T*?Z_Y`8OZ<8``!0$+!DIQ@``%`0L&A8$-!:#>$8$E`0
ML&Q8$+!L$A&GA``/6""P;%@0T%8-X1@24!"P:%@0L&C2`[!D$`!8$+!D&"%8
M0+"HF+^PG`?T`$`@(`!`(&"0;_`8#="G^O]P&+]0(+!DIQ@``%`0L("G.```
M4#"PA%@0T6+2%[!H$`"G&```4!"PC*<X``!0,+"(I_0`:5@@L(!8$-%>#>$8
M$E`0L(18$+"$$A&GA``+6!"PA$,0$`!4$-%:$A&G=``+6""P@%@PL&18$-%6
M#>&G]`!$6""PA%@PL&18$-%2#>$8$A(1IW0`.5@@L&18$-%.#>$8PE@0T4I8
M$!``&"%8$-%.#>$8$AK!6""PA%@0T4X-X1@2&ARG&@`"&"%8$-%&#>$8$E`0
ML(Q8$-%*6%`0`%@0T4)8(+",&#%80+!D6&"PA%@0T3X-X5@@L(!8,+",6!#1
M5@WA6!"PB*<:``%0$+"(6!"PB*<H\`")$``"03"PD!H36#$OV%`PL(!8$+"`
M0Q`0`%00T5H2$:=T_X580+#(F&^PJ`?T!P<`0"0@`$!Z,`!`(2``0.)<`$`?
MX`!`(0``0"B,````_P!`*%@`0'M,D&_P&`W06O#:.AB_4""P;*<H``!8$-HV
M4"&P`*=(``!8,-HR4$.P`*<H``!8$-HN4"&P`%@0VBI8,-HF03.P`-(/,``0
M`%@0VB)80-H>042P`-(70``0`%@0VAI8(-H602*P`-(+(``0`%A`VA)8,-H.
M4$.P`%@@V@I8$-H&4"&P`*=(``!8,-H"4$.P`*<H``!8$-G^4"&P`*=(``!8
M,-GZ4$.P`*<H``!8$-GV4"&P`%@0V?(8(5@0V>X-X1@26##:+E`3L`!80-HN
M6!2P`!(1IX0`(%@@VBY8$K``0Q`0`%00V>H2$:>$`!58,-HN6".P`%@0V>8-
MX5A`VBY8)+``6!#9X@WA&!)0$+!HI_0$"5@0V=X-X1@26"#9_E`2L`!8,-G^
M6!.P`!(1IW0`6*<8``!80-G:4!2P`*?T`"M8,-HR6".P`%@0V>X-X1@26$#:
M+E`4L`!8(-HN6!*P`!(1IX0`#E@PVBY8([``6!#9X@WA&!)80-G^4!2P`%@@
MV=I8$K``IQH``5@PV=I0$[``6$#9_E@4L``2$:=T`"!8(-G:6!*P`*<H\`")
M$``"6##9UD$SL``:$U@Q+Y180-HR4#2P`%A`VC)8%+``0Q`0`%00V>H2$:=T
M_[18(-G^6!*P`!(1IW0`"EA`V=)8,-G^4$.P`*?T`$%8$-G^6"&P`%@0V<Y0
M(;``I_0`+%@0V<H-X1@26"`0`%@PV<Y8$[``0Q`0`%00V>J)$``!&A)($!``
M5!#9QE00V<(2$:=T``A80-G.6!2P`))?$`!8(-G.6!*P`*<:``%8,-G.4!.P
M`%A`V<Y8%+``0Q`0`%00V>H2$:=T_\VG*```6!#9VE`AL`"G]`"*6##:,E@C
ML`!8$-GN#>$8$EA`VBY0%+``6"#:+E@2L``2$:>$`&VG*```6!#9O@WA&!)8
M$!``&"%8$-FZ#>$8$A@A6!#9M@WA&!)8,-HN6".P`!@Q6!#9L@WA&!(2$:=T
M`$^G*```6!#9O@WA&!)8$!``&"%8$-FZ#>$8$A@A6!#9M@WA&!)8$!`05!#9
MKJ<>0`"GA``<IR@``%@0V;X-X1@26!`0`!@A6!#9N@WA&!(8(5@0V;8-X1@2
M6!`0$%00V:Y9$-FJIW0`&UA`VBY8)+``IS@``E@0V:8-X1@2$A&G=``.6!#:
M+E@AL`!8$-GB#>$8$E@@VC90$K``6##9VE@3L`"G&@`!6$#9VE`4L`!8(-HV
M6!*P`!(1IW0`(%@PV=I8$[``IRCP`(D0``)80-G6042P`!H46$$OH%@PVC)0
M0[``6"#:,E@2L`!#$!``5!#9ZA(1IW3_5:=(``!8,-G:4$.P`*?T`'>G*```
M6!#9O@WA&!)8$!``&"%8$-FZ#>$8$A@A6!#9M@WA&!)8,-HN6".P`!@Q6!#9
ML@WA&!(2$:=T`$^G*```6!#9O@WA&!)8$!``&"%8$-FZ#>$8$A@A6!#9M@WA
M&!)8$!`05!#9KJ<>0`"GA``<IR@``%@0V;X-X1@26!`0`!@A6!#9N@WA&!(8
M(5@0V;8-X1@26!`0$%00V:Y9$-FJIW0`&UA`VBY8)+``IS@``E@0V:8-X1@2
M$A&G=``.6!#:+E@AL`!8$-GB#>$8$E@@VC90$K``6##9VE@3L`"G&@`!6$#9
MVE`4L`!8(-HV6!*P`!(1IW0`(%@PV=I8$[``IRCP`(D0``)80-G6042P`!H4
M6$$ON%@PVBY00[``6"#:+E@2L`!#$!``5!#9ZA(1IW3_:%@PVC98([``6!#9
MH@WA&,)80-H.6"2P`%@0V:(-X1@2&L%8$-G^6"&P`%@0V:(-X1@2&L%8,-H&
M6".P`%@0V:(-X1@2&ARG&@0`6$#9]E`4L`!8(-GV6!*P`!@A6!#9G@WA&!)8
M,-GZ4!.P`%@0V9I84!``6!#9EEA`V?Y81+``4$#P8%@PV?I8([``&#%8$-HV
M6$&P`%@0V@Y88;``6!#9D@WA6##9^E@CL`"G.`'M6!#9C@WA6!#9BA@A6!#9
M[@WA&!)80-HN4!2P`%@0L&Q8P!``6!#:+E@AL`!8$-GB#>$8$A@L&#%8$-F&
M#>$8$E@@V@)0$K``6##:`E@3L``2$:=T``I8$+!L6"`0`%A`V@)0)+``6!#9
M@@WA&!(2$:=T`3!8,-H"6".P`*<X``!8$-E^#>$8$EA`V7I0%+``6"#9>E@2
ML``2$:>$`1M8,-EZ6".P`*<X__^G2/_NIU@``E@0V78-X1@;IQH`B%A`V7I8
M)+``&#&G2``&6!#9<@WA0Q"PB%00V>H2$:=T`&)#$+")5!#9ZJ<>`$.G=`!:
M0Q"PBE00V>JG'@!!IW0`4D,0L(M4$-GJIQX`0Z=T`$I#$+",5!#9ZJ<>`$BG
M=`!"0Q"PC500V>JG'@!%IW0`.E@0V7I8(;``ISC__Z=(_\:G6``"6!#9=@WA
M&!NG&@"(6##9>E@CL``8,:=(`"E8$-ER#>%8$-F:6%`0`%@0V6X8"Z<*`(A8
M0-H&6$2P`%!`\&!8,-GZ6".P`!@Q6!#9^EA!L``88%@0V9(-X:?T`,`8&UH0
MV6H8(5@0V68-X:?T`!`8&UH0V6H8.Z<Z`(@8(5@0V6)80;``6!#97@WA&!NG
M&@"(6##9>E@CL``8,5A`V5I8$-ER#>$8$EA`V6)0%+``6"#98E@2L``2$:<D
M_]M8,-EZ6".P`%@0V58-X1@;IQH`=!@[6C#9:A@A6!#94@WAIQ@``%A`V4Y0
M%+``I_0`)5@@V4Y8$K``B1```1@K6B#92AHA6##93E@3L`!#$;!TIT@`_Q1!
M6!#91A@Q6!#9D@WA6$#93E@4L`"G&@`!6"#93E`2L`!8,-E.6!.P`*<>`!.G
MQ/_7IQ@``%A`V4)"%+``6!#9FEA0$`!8$-EN&`M:`-E*6"#:!E@BL`!0(/!@
M6##9^E@CL``8,5@0V?I80;``&&!8$-F2#>&G]``H6!#9/E@PV3H8(5@0V38-
MX5@0V9I8P!``6!#9,@WA&`)8$-DN6"#:!E@BL`!0(/!@6##9^E@CL``8,5@0
MV?I80;``&%P88%@0V9(-X5@0V?(8(5A`V?I8-+``6!#9-@WA6!#9^E@AL`!8
M$-GF#>%8(-GZ6"*P`%`@L&A8$+!H&"%:L-G66$"P.)AOL!@']`!`?`(`0!L@
M`$`HC`!`>N8`0'I4``"!$P!`>_P``(#K``"!>`!`66P`0"#```"```!`5>``
M`(%T`$!54```@(@`0'OL`$`=H`!`'*```(%P`$`BX`!`-:@`0"X<`$![,`!`
M&T``0"0@`$![X@!`XE@`0"$@`$`?X`!`'F```*````#P``!`>10`0"'``$`=
M@`!`(X````@```#__P!`'N```(%,`$![V@``@8```(%(`$!:Z`!`(V``0%M,
M````_P!`*%@`0'H6``"!?```@6P``(%H``"!9```@6``0'M(``"!7`!`>]0`
M`($4`$![=```@2``0'N<``"!.`!`>\0``(%8``"!5```@5#__WZ`D+_P+`W0
MI_K_(!B_4""P9%`PL&"G&```4!"PV%@@L&18$-&F#>$8$E`0L-!8$+#0$A&G
MA`"9I_0`>U@0L-2G&@`36##1HA@A6!#1G@WA&!(2$:>$`&U8$+#4IQH`$U@P
MT9H8(5@0T9X-X1@2$A&GA`!?6""P9%@0T98-X1C"6!"PU*<:`!,8(5@0T98-
MX1@2&ARG&@`"4!"PW%@0L-P8(5@0T9(-X1@24!"PV%A0L-2G6@`36!#1CE@@
ML-@8,5A`L&18$-&*#>$8&Z<:`&A8(+#8&#%8$-&&#>$8$J<>__^GA``86!"P
M>%00T8*G'D``IW0`$%@0L&`2$:>$``M8(+#8IS@``5@0T7X-X:?T``=8(+#8
M6!#1>@WA6""PV%@0T78-X:<8``!0$+#86""PT%@0T7(-X1@24!"PU%@0L-02
M$:=T_WQ8(+#06!#1;@WA6!"P9!(1IX0`!U@@L&18$-%J#>%80+$8F+^Q#`?T
M!P<`0"%@`$`@H`!`'X``0!X``$`@``!`9OP``/```$!XX`!`)"``0'P4`$`A
M(`!`'^``0'P0`$`CP`!`>BX`0!Z@D+_P+`W0I_K_D!B_4""P9%@@L&18$-"N
M#>$8$E`0L&A8(+!H6!#0J@WA&!)0$+!L6!#0I@WA&!(2$:>$`"M8$+!D$A&G
MA``F6!"P9$,0$`!4$-"B$A&GA``=6!#0GE@@L&P8,5@0T)H-X1@261"P;*=T
M`!!8(+!DIS@``5@0T)8-X5@@L&BG.```6!#0E@WA6$"PJ)B_L)P']`<'`$!F
M_`!`(0``0'O4````_P!`-:@`0#%4`$`QV)"_\"P-T*?Z_Y`8OU`PL&RG*```
M6!#3!@WA&!)8$!``&"%8$-,"#>$8$A@A6!#2_@WA&!)8$!``6,`0!*<H``!8
M$-,&#>$8$E@0$``8(5@0TP(-X1@2&"%8$-+Z#>$8$D,0$`!"$,`8IR@``%@0
MTP8-X1@26!`0`!@A6!#3`@WA&!(8(5@0TOX-X1@26!`0`%C`$`2G*```6!#3
M!@WA&!)8$!``&"%8$-,"#>$8$A@A6!#2]@WA&!)8$!``6!`0$(@0`!=`$,`:
MIR@``%@0TP8-X1@26!`0`!@A6!#3`@WA&!(8(5@0TOX-X1@26!`0`%C`$`2G
M*```6!#3!@WA&!)8$!``&"%8$-,"#>$8$E@PTO(8(:=(``!8$-+N#>$8$E`0
MP!RG*```6!#3!@WA&!)8$!``&"%8$-,"#>$8$A@A6!#2_@WA&!)8$!``6,`0
M!*<H``!8$-,&#>$8$E@0$``8(5@0TP(-X1@2&"%8$-+J#>$8$E@0$`!0$,`@
MIR@``%@0TP8-X1@26!`0`!@A6!#3`@WA&!(8(5@0TOX-X1@26!`0`-(#L&00
M!*<H``!8$-,&#>$8$E@0$``8(5@0TP(-X1@2&"%8$-+F#>$8$E@0$``2$:>$
M`!NG*```6!#3!@WA&!)8$!``&"%8$-,"#>$8$A@A6!#2Y@WA&!)8$!``T@.P
M:!!LI_0`!J<8``!0$+!H6""P9-(#("2P:*<H``!8$-,&#>$8$E@0$``8(5@0
MTP(-X1@2&"%8$-+^#>$8$E@0$`!8$!`$IR@``%`@$"BG*```6!#3!@WA&!)8
M$!``&"%8$-,"#>$8$A@A6!#2_@WA&!)8$!``6!`0!*<H``!0(!`LIR@``%@0
MTP8-X1@26!`0`!@A6!#3`@WA&!(8(5@0TOX-X1@26!`0`%C`$`2G*```6!#3
M!@WA&!)8$!``&"%8$-,"#>$8$A@A6!#2X@WA&!)8$!``4!#`,%A`L*B8O["<
M!_0'!P!`(P``0"&@`$`;X`!`(H``0'M(`$`<0`!`'"``0!L``$`=@`!`(X"0
MO_`L#="G^O^8&+]0,+!DIR@``%@0T'8-X1@26!`0`!@A6!#0<@WA&!(8(:<X
M__]8$-!N#>&G*```6!#0=@WA&!)8$!``&"%8$-!R#>$8$E@PT&H8(:=(``!8
M$-!F#>%80+"@F+^PE`?T!P<`0"1@`$!I9`!`'B``0!V``$`C@)"_\"P-T*?Z
M_V@8OU`PL'2G&```4!"PC*<H``!8$-9J#>$8$E@0$``8(5@0UF8-X1@2&"%8
M$-9B#>$8$I(!$`!8$-9>&"%8$-9:#>$8$E`0L)!8$+"0$A&GA``76!"PD$,0
M$`!4$-96IQX`,:=T``U8$+"0IQH``4,0$`!4$-96$A&GA``%6!#64@WAIR@`
M`%@0UFH-X1@26!`0`!@A6!#69@WA&!)8,-9.&"&G2``!IU@`"U@0UDH-X1@2
M4!"P>%@0L'@2$:>$`,)8$+!X6!`0#-(#L'P0&*<H``%0(+"(I_0`=Z<H``!8
M$-9J#>$8$E@0$``8(5@0UF8-X1@26$"PB*=*__\8(5@PL'RG6```6!#61@WA
M&!)0$+"`6!"P@!(1IX0`7U@0UD)8(!``6!"PB(D0``(:$M(#L&`0`%@0L(!8
M$!``6!`0"%00UCX2$:>$``M8$+"`6!`0`-(#L&00#*?T`!^G*```6!#6:@WA
M&!)8$!``&"%8$-9F#>$8$A@A6!"P@%@0$``8,:=(``"G6``"6!#6.@WA&!)0
M$+!D6""P8%@PL&18$-8V#>$8$A(1IW0`%U@0L(RG&@`!4!"PC%@0L(BG&@`!
M4!"PB%@0UC)8(!``6!"PB!D2IT3_A%@0UC)8$!``IQK__UD0L(RG=``MIQ@`
M`5`0L(BG]``>IR@``%@0UFH-X1@26!`0`!@A6!#69@WA&!(8(5@PL'Q8$-8N
M#>$8$E`0L(18$+"(IQH``5`0L(A8$-8R6"`0`%@0L(@9$J=$_]VG*```6!#6
M:@WA&!)8$!``&"%8$-9F#>$8$E@PUBH8(:=(``&G6``%6!#62@WA&!)0$+!X
M6!"P>!(1IX0`0:<H``!8$-9J#>$8$E@0$``8(5@0UF8-X1@2&"%8$+!X6!`0
M#%@0$`!80-8F&#%8$-8B#>%8$+!X6!`0#%@0$`!8$!`(5!#6'A(1IX0`&J<H
M``!8$-9J#>$8$E@0$``8(5@0UF8-X1@2&"%8$+!X6!`0#%@0$``8,5@0UAH-
MX:<H``!8$-9J#>$8$E@0$``8(5@0UF8-X1@26##6%A@AIT@``:=8``58$-9*
M#>$8$E`0L'A8$+!X$A&GA`!.IR@``%`@L)18$-82&"%8$-9:#>$8$E`0L)18
M$+"4$A&GA``>IR@``%@0UFH-X1@26!`0`!@A6!#69@WA&!(8(5@0L'A8$!`,
M6!`0`!@Q6$"PE%@0UB(-X:?T`""G*```6!#6:@WA&!)8$!``&"%8$-9F#>$8
M$A@A6!"P>%@0$`Q8,!``6!#60E@0$`!8$!``&$%8$-8.#>&G*```6!#6:@WA
M&!)8$!``&"%8$-9F#>$8$A@A6!#68@WA&!*2`!``IR@``%@0UFH-X1@26!`0
M`!@A6!#69@WA&!(8(5@0U@H-X1@2IR@``%`@$`!8$-8&&"%8$-9:#>%8$-8"
M4"`0`%@0U@)8$!``$A&G=`"<6!#60E@0$``8(5@0U?X-X5@0U@)0(!``6!"P
M>%@0$`Q8$!``6!`0"%00UCX2$:>$``U8$+!X6!`0#%@0$`#2`[!H$`RG]``A
MIR@``%@0UFH-X1@26!`0`!@A6!#69@WA&!(8(5@0L'A8$!`,6!`0`!@QIT@`
M`*=8``)8$-8Z#>$8$E`0L&A8$-9"6!`0`%@@L&@8,5@0U?H-X1@24!"PB%@0
MUD)8$!``T@.P;!``6!"P>%@0$`Q8$!``6!`0"%00UCX2$:>$``U8$+!X6!`0
M#%@0$`#2`[!P$`RG]``AIR@``%@0UFH-X1@26!`0`!@A6!#69@WA&!(8(5@0
ML'A8$!`,6!`0`!@QIT@``*=8``)8$-8Z#>$8$E`0L'!8$-7V&"%8,+!L6$"P
M<%A0L(A8$-7R#>%8$-8"6!`0`!@AIS@![5@0U>X-X1@24!"PB%@0L(@2$:>$
M`"!8$+"(IQX`$:>$`!I8$+"(IQ[__Z>$`!18$-9"6!`0`%@P$`!8$-8"6$`0
M`%@0U>H8(5A0L(A8$-7R#>%80+#0F+^PQ`?T`$!\6@!`&T``0"(@`$!\*@!`
M'\``0%RX`$#RG`!`>A8`0"/@`$`EZ`!`>B``0'PH`$`A0`!`````0!U``$!\
M(@!`?"``0!S@`$#RH`!`(\``0"2````$``!`\J0`0""``$`=``!`?!H`0#/`
M````_P!`*%@`0'HX`$`>@`!`'8``0".`D&_P&`W0I_K_F!B_IR@``%@0T(8-
MX1@26!`0`!@A6!#0@@WA&!(8(5@0T'X-X:<H``!8$-"&#>$8$E@0$``8(5@0
MT((-X1@26##0>EA`T'984-!R6`#0<J<H``!0(/!@&"$88%@0T&X-X5A`L*"8
M;["`!_0`0!]``$![2`!`;/0`0'RH`$`EA`!`'8``0".`D&_P&`W0I_K_>!B_
M4""P?%`PL'A00+!T&!NG&@!\&#NG.@!X&$NG2@!T&"%8$-0>#>%8$-0:6##4
M%EA`U!88(5@0U!(-X:<H``!8$-0.#>$8$D,0$`!4$-0*$A&G=``Q6!#4!@WA
M6!#4`E`@$`!8$-0"6!`0`!(1IW0`!Z<H``%8$-/^#>%8$-0"6!`0`!@A6!#3
M^@WAIR@``%@0T_8-X1@26!`0`!@A6!#3\@WA&!(8(5@0T^X-X1@2D@`0`*<H
M``!8$-/V#>$8$E@0$``8(5@0T_(-X1@2&"%8$-/J#>$8$A@A0Q`@`%80T^9"
M$"``IR@``%@0T_8-X1@26!`0`!@A6!#3\@WA&!(8(5@0T^H-X1@2&"%#$"``
M5A#3XD(0(`!8$+!\IQH`!;.5``%@`+!@$A&GI``):`"P8.T`TXX`&F``L&"S
M=0``[0"P8``:D@"P;^T`TX8`&:?4``22`;!O0Q"P;U<0T^)4$-0*$A&G=``(
M6!#3WA@A6!#3V@WA6!"P?*<:``6)$``"&"%8$-/6#>$8$A@A6!#3TE`@$`!8
M$-/26"`0`%@0L'A8$!``4!`@`%@0T])8$!``IQH`!-(#$`#3SE@0T])8$!``
MIQH`"-(#$`#3RE@0T\:G*``#4"`0`%@0T])8(!``6!#3QE@0$`")$``"&A+2
M`Q``T\)8$-/&6!`0`!@AIRH``5@0T\90(!``IQ@``5`0L(2G]``E6!#3TE@P
M$`!8$-/&6!`0`%H0L(08(:<8``$;$HD0``(3$1HQ6""P>%@0L(2)$``"&A)8
M$!``4!`P`%@0L(2G&@`!4!"PA%@@L'Q8$+"$&1*G1/_86!#3TE@P$`!8(+!\
M6!#3QE@0$``:$A@AIQ@``1L2B1```A,1&A.G*```4"`0`%@0U`)8,!``6""P
M?%@0T\98$!``&A(80:=*__]8$-/26%`0`%@0T[X8(Q@QIV@``%@0T[H-X1@2
M4!"P@%@0L(`2$:=T``U8$-0"6!`0`!@A6!#3M@WA&!)0$+"`6!#4`E@0$``8
M(5@0T[(-X5@0TZX8(5@0TZH-X1@2$A&G=``B6!#3IE@0$``2$:=T``Q8$-.B
M&"%8$-.J#>%8$-.F4"`0`%@0TZ98$!``$A&GA``*6!#3IE@0$``8(5@0TYX-
MX5@0U`)8$!``&"%8$-.:#>%8$-.6#>%8$+"`&"%80+#`F&^PH`?T!P=!S___
M_X```$'P`````````$`>P`!`&V``0&BL`$!Z%@!`\IP`0"A8`$!Z2`!`(.``
M0!S``$`;@`!`<V@`0'S"`$#RH`!`?-``0'R^`$#RI`!`(F``0"(@`$#B>```
M``$````"`$`CH`!`(D``0!V``$`C@`!`'V``0"0``$#RF`!`'<````#_`$`=
MX`!`>"``0!N@`$`?(`!`(T"0S_`P#="G^O^@6,#0.E@0T#9!S-``05'``!)5
MIX0`!%A04`!8$-`R3>'``%A`\)B8S_"0!_0'!___.W0```%(``!HY@?^!P>0
M;_`8#="G^O^@6,#0;E@0T&H8<D',T``8@QB43>'``%@0T&88+%H@T&)!$<``
M&R&*(``"$B*GA``3&&$8LJ>H```86HE0``(8)Q@X&$FGJ@`!6!5@``WAI[;_
M]5A`\)B8;_!X!_0'!____O3___[T__]#-```:)Z0S_`P#="G^O^@6,#0*E@0
MT"880T',T``8,J<H``--X<``6$#PF)C/\)`']/__.O0``&@FD,_P,`W0I_K_
MH%C`T"I8$-`F&$-!S-``&#*G*``#3>'``%A`\)B8S_"0!_3__STT``!G\I#/
M\#`-T*<H\`!8$-`^I_K_H%@2'_RG'O__IX0`#5C`T#JGRO_\#>%8$,``IQ[_
M_Z=T__E80/"8F,_PD`?T!P<`0.```$#@!)!O\!BGU0`$``!G=!@?I_K_H%`0
M\`!8P-``&LVG)0`$__^K/%@P(`!-XR``6$#PF)AO\'@']`<'``(``7!E<FQX
M<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`+W!R;V,O<V5L9B]E
M>&4``"\`.@`O<')O8R\E:2\E<P!E>&4`4$%27U1%35```%!!4E]04D]'3D%-
M10``+@`E<R5S)7,``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?05)'0P``4$%27T%21U9?
M,```4$%27T=,3T)!3%]$14)51P``4$%27T=,3T)!3%]435!$25(`4$%27U1-
M4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``%!!4E]#
M3$5!3CT``#$`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```$Q$
M7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42```4$%42```1%E,
M1%],24)205)97U!!5$@```````!`>PH`0'L:`$![(@!`>S``0'LV`$![2%53
M15(``%5315).04U%````0'MD`$![:@!`>TA435!$25(``%1%35!$25(`5$5-
M4```5$U0`````$!ZK`!`>X``0'N(`$![D`!`>Y8`0'M(0SI<5$5-4``O=&UP
M``````!`>[0`0'N\`$!Z+@!`>TAP87(M``!365-414T``"5S)7,E<R5S```E
M<R5S8V%C:&4M)7,E<P``)3`R>```)7,E<W1E;7`M)74E<P`N+@``)7,O)7,`
M05)'5@``&`!P97)L```P`"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@
M86)O<G1I;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E
M;7!O<F%R>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET
M:"`E:2X*`$EN=&5R;F%L<SHZ4$%2.CI"3T]4```M90``+2T`````<&%R+G!L
M```C(2]U<W(O8FEN+W!E<FP*"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S
M8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM
M92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34Y"@IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI
M.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E
M;7`["B`@("!R;61I<B`D=&]P9&ER.PH*("`@(&EF("@M9"`D<&%R7W1E;7`I
M('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG('5N;&EN:VEN9R!T
M:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@("`@("`C('1Y<&EC
M86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I<V%L;&]W('5N;&EN
M:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A;F0@97AE8W5T86)L
M97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A(&)A8VMG<F]U;F0*
M("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I;&5S(&%R92!N;R!L
M;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*"B`@("`@("`@;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G
M=&UP6%A86%@G+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M
M9"<L"B`@("`@("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@
M("`@(",@0F5C875S92!T:&4@<&%R7W1E;7`@9&ER96-T;W)Y(&ES(&=O:6YG
M('1O(&)E(&1E;&5T960@:6X@80H@("`@("`@(",@8F%C:V=R;W5N9"!P<F]C
M97-S+"!T:&4@<&%R96YT('!R;V-E<W,@:60@;6%Y(&)E(')E=7-E9"!B969O
M<F4@=&AE"B`@("`@("`@(R!B86-K9W)O=6YD('!R;V-E<W,@8V]M<&QE=&5S
M+B`@5&\@96YS=7)E('1H870@=&AE('1E;7!O<F%R>0H@("`@("`@(",@9&ER
M96-T;W)Y(&1O97,@;F]T(&=E="!R975S960@=VAI;&4@:70@:7,@8F5I;F<@
M9&5L971E9"P@=')Y('1O"B`@("`@("`@(R!R96YA;64@:70@=&\@82!N86UE
M('1H870@:7,@<F5L871E9"!T;R!T:&4@=&5M<&]R87)Y('-C<FEP="!F:6QE
M+@H*("`@("`@("!M>2`D=&UP;F%M92`]("A&:6QE.CI3<&5C+3YS<&QI='!A
M=&@H)'1M<"T^9FEL96YA;64I*5LR73L@(R!F:6QE;F%M90H@("`@("`@("1T
M;7!N86UE(#U^(',O7"Y;7BY=*B0O+F1I<B\["B`@("`@("`@;7D@)&YE=T1I
M<B`]($9I;&4Z.E-P96,M/F-A='!A=&@H"B`@("`@("`@("`@("A&:6QE.CI3
M<&5C+3YS<&QI='!A=&@H)'!A<E]T96UP*2E;,"XN,5TL("1T;7!N86UE*3L*
M("`@("`@("!I9B`H<F5N86UE("1P87)?=&5M<"P@)&YE=T1I<BD@>PH@("`@
M("`@("`@("!O=71S*")296YA;65D("1P87)?=&5M<"!T;R`D;F5W1&ER(BD[
M"B`@("`@("`@("`@("1P87)?=&5M<"`]("1N97=$:7(["B`@("`@("`@?0H*
M("`@("`@("!I9B`H)%Y/(#U^(&TO=VEN,S(O:2D@>PH@("`@("`@("`@("!P
M<FEN="`D=&UP("(*.FQO;W`*<FUD:7(@+W$@+W,@7"(D<&%R7W1E;7!<(@II
M9B!E>&ES="!<(B1P87)?=&5M<%PB(&=O=&\@;&]O<`IR;61I<B!<(B1T;W!D
M:7)<(@IR;2!<(B(@+B`D=&UP+3YF:6QE;F%M92`N(")<(@HB.PH@("`@("`@
M("`@("!C;&]S92`D=&UP.PH@("`@("`@("`@("!M>2`D<')O8SL*("`@("`@
M("`@("`@5VEN,S(Z.E!R;V-E<W,Z.D-R96%T92@*("`@("`@("`@("`@("`@
M("1P<F]C+"`D14Y6>T-/35-014-]+`H@("`@("`@("`@("`@("`@(B1%3E9[
M0T]-4U!%0WT@+V,@7"(B("X@)'1M<"T^9FEL96YA;64@+B`B7"(@/FYU;"`R
M/FYU;"`B+`H@("`@("`@("`@("`@("`@,2P@3D]234%,7U!224]225197T-,
M05-3+"`B+B(*("`@("`@("`@("`@*3L*("`@("`@("!](&5L<V4@>PH@("`@
M("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*=VAI;&4@6R`M9"`G)'!A
M<E]T96UP)R!=.R!D;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*9&]N90IR;61I
M<B`G)'1O<&1I<B<*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@
M("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@
M("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R
M/B8Q("8G.PH@("`@("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@("`@("!S
M>7-T96TH)&-M9"D["B`@("`@("`@?0H@("`@("`@(&]U=',H<7$H4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P*2D["B`@
M("!]"GT@?0H*0D5'24X@>PH@("`@26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*"B`@("!E=F%L('L*
M"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE>&ES=',@)$5.5GM005)?05)'5E\P
M?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*("`@($!!4D=6(#T@;6%P("1%
M3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D[
M"B`@("`D,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["B`@("!F;W(@
M*&ME>7,@)45.5BD@>PH@("`@("`@(&1E;&5T92`D14Y6>R1??2!I9B`O7E!!
M4E]!4D=67R\["B`@("!]"GT*"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["@HC(&9I>"`D<')O9VYA;64@:68@:6YV;VME9"!F<F]M(%!!5$@*;7D@
M)4-O;F9I9R`]("@*("`@('!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*("`@(%]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["@I?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*"B,@
M36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N9"!E>'1R86-T:6YG(&)U;F1L960@
M;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*("`@
M(&QO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PH*("`@(",@0VAE8VL@
M9FEL92!T>7!E+"!G970@<W1A<G0@;V8@9&%T82!S96-T:6]N('M[>PH@("`@
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["B`@("!B:6YM;V1E
M*%]&2"D["@H@("`@;7D@)&)U9CL*("`@('-E96L@7T9(+"`M."P@,CL*("`@
M(')E860@7T9(+"`D8G5F+"`X.PH@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B
M7&Y005(N<&U<;B(["@H@("`@<V5E:R!?1D@L("TQ,BP@,CL*("`@(')E860@
M7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["@H@("`@)&1A=&%?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@("`C('U]?0H*("`@(",@17AT<F%C
M=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO<GD@>WM["B`@("!M>2`E<F5Q=6ER
M95]L:7-T.PH@("`@=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["B`@("`@("`@
M<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!M>2`D9G5L;&YA;64@/2`D8G5F
M.PH@("`@("`@(&]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N
M+BXI*3L*("`@("`@("!M>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PH@("`@("`@(&UY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@("`@<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@("!I9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*("`@("`@("`@("`@;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I
M;&4H)&5X="P@)&-R8RD["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I
M;G0@)&]U="`D8G5F.PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@
M("`@("`@("`@("`@(&-H;6]D(#`W-34L("1F:6QE;F%M93L*("`@("`@("`@
M("`@?0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B`@("`@("`@("`@("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*("`@("`@("!]"B`@
M("`@("`@96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PH@("`@("`@("`@("`C('-H;W5L
M9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H*0H@("`@("`@("`@("!M>2`D9FEL
M96YA;64@/2`B)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["B`@("`@
M("`@("`@(&]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PH@("`@("`@("`@
M("!O<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@
M("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@<')I;G0@)&]U
M="`D8G5F.PH@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["B`@("`@("`@("`@("`@("!B=68@/3X@)&)U9BP*("`@
M("`@("`@("`@("`@(&-R8R`]/B`D8W)C+`H@("`@("`@("`@("`@("`@;F%M
M92`]/B`D9G5L;&YA;64L"B`@("`@("`@("`@('T["B`@("`@("`@?0H@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@?0H@("`@(R!]?7T*"B`@("!L
M;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@("`@;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PH*("`@("`@("!R971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["@H@("`@("`@(&UY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*("`@("`@("`@("`@;7D@)&ME>3L*
M("`@("`@("`@("`@9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["B`@
M("`@("`@("`@("`@("!N97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*("`@
M("`@("`@("`@("`@("1K97D@/2`D7SL@;&%S=#L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I
M;F5D*"1K97DI.PH@("`@("`@('T@;W(@<F5T=7)N.PH*("`@("`@("`D24Y#
M>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PH*("`@
M("`@("!I9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PH@("`@("`@("`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D[
M"B`@("`@("`@("`@('!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PH@("`@
M("`@("`@("!S965K*"1F:"P@,"P@,"D["B`@("`@("`@("`@(')E='5R;B`D
M9F@["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("!M>2`H
M)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC
M<F-]*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1F
M:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&]P96X@;7D@)&9H+"`G/"<L("1N
M86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*"B`@("`@("`@9&EE(")"
M;V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B([
M"B`@("!]+"!`24Y#*3L*"B`@("`C($YO=R!L;V%D(&%L;"!B=6YD;&5D(&9I
M;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ92!S:&%R960@;V)J96-T('!R;V-E
M<W-I;F<*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E(%!!4CHZ
M2&5A=GD["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%
M>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@=')Y(&=E='1I;F<@:&5L<&5R(&UO
M9'5L97,@9G)O;2!W:71H:6X*("`@(')E<75I<F4@24\Z.D9I;&4["@H@("`@
M(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P(&EN"B`@("!W:&EL92`H;7D@)&9I
M;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["B`@("`@("`@("`@(",@<F5Q
M=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E>&5C=71A8FQE(&9I;&5S"B`@("`@
M("`@("`@(&EF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PH@("`@("`@
M("`@("`@("`@<F5Q=6ER92`D9FEL96YA;64["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`C(%-K:7`@06-T:79E
M4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L(&9I;&4Z"B`@("`@("`@("`@("`@
M("!D;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@("`@("!D
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PH@("`@?0H*("`@(",@
M?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B`@
M("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*(R!]?7T*"B,@07)G
M=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@
M)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["@HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["@HC($1O;B=T('-W86QL;W<@87)G=6UE
M;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P
M=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*
M("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P
M87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N
M7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(&UY($!A
M9&1?=&]?:6YC.PH@("`@=VAI;&4@*$!!4D=6*2!["B`@("`@("`@)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@
M("`@("`@:68@*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("!P=7-H($!A9&1?
M=&]?:6YC+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=-
M)RD@>PH@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@("`@('T*("`@
M("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@("`@('5N<VAI9G0@
M0'!A<E]A<F=S+"`D,CL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q
M("=/)RD@>PH@("`@("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@)&)U;F1L92`]
M("=S:71E)SL*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=")RD@
M>PH@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@("`@("`@)'%U:65T(#T@
M,3L*("`@("`@("!]"B`@("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@
M("`@("`@("!O<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A
M;FYO="!O<&5N(&QO9SH@)"$B.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H
M)#$@97$@)U0G*2!["B`@("`@("`@("`@("1C86-H95]N86UE(#T@)#(["B`@
M("`@("`@?0H*("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@(&EF("AM
M>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@("`@("`@("!D96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@:6YI=%]I;F,H*3L*("`@
M("`@("`@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("`@("`@("`@("9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@
M("!E>&ET.PH@("`@("`@('T*("`@('T*"B`@("!U;G-H:69T($!)3D,L($!A
M9&1?=&]?:6YC.PI]"@HC(%A86"`M+2!A9&0@+2UP87(M9&5B=6<@<W5P<&]R
M="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N9&QI;F<@>WM["FEF
M("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U
M:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@
M("`@?0H*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@;7D@)'II
M<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A
M<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@("`@;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@("!M>2`E
M96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@("1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]?B!S+UY<
M4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN<'5T(&%N
M9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*("`@(&EF
M("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2*3L*("`@
M("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2
M/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T:"@D;W5T
M*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@("`@("`@
M)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@("`@(#`W
M-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*"B`@("`D
M+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968[
M"B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V86P@)'9A
M;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@)&QO861E
M<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@+B`D<V5T
M("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*("`@("`@
M("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@("`@)"\@
M/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D(&UO9'5L
M97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["B`@("`@("`@:6YI=%]I;F,H*3L*("`@("`@("!R97%U:7)E7VUO9'5L
M97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@("`@("`@("`@("!L
M96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@?2!G<F5P('L*("`@
M("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P('L*("`@("`@("`@
M("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@("`@("`H)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@("`@("`@("`@("`@
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*("`@("`@("!]
M($!)3D,["@H@("`@("`@(&EF("@D0V]N9FEG>U]D96QI;7T@97$@)UQ<)RD@
M>R!S>UQ<?7LO?6<@9F]R($!I;F,@?0H*("`@("`@("!M>2`E9FEL97,["B`@
M("`@("`@+UY?/"@N*RDD+R!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z
M.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@
M("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*
M"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@
M("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@
M("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2![
M"B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R
M*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ
M6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@
M("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@
M("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@
M>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*
M("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@
M("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I
M.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR
M968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE
M+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@
M("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@
M("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F
M<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S
M+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@
M("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB
M*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@
M("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T
M94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@
M("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@
M?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!
M4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI3
M2$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I
M(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D[
M"B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE
M(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@
M("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<
M;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@
M)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E
M("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M
M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@
M:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@
M("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<[
M"B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A
M.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]
M("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@
M("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@
M("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@
M("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*
M("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@
M("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@
M("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@
M("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@
M)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC
M871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@
M("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU
M;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H
M4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES
M=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@
M("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@
M('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H
M97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S
M<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@
M("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA
M;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@
M("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M
M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I
M<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@
M(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q
M=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E
M('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P
M.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@(')E<75I<F4@
M1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I
M;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!#
M;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R97%U:7)E($E/
M.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*("`@(')E<75I
M<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@(')E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@979A;"![(')E<75I<F4@
M0W=D('T["B`@("!E=F%L('L@<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![
M(')E<75I<F4@5VEN,S(Z.E!R;V-E<W,@?3L*("`@(&5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O
M9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"G-U8B!?<V5T7W!A<E]T
M96UP('L*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!A<E]T96UP(#T@)#$["B`@("`@
M("`@<F5T=7)N.PH@("`@?0H*("`@(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@
M("`@("AM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`H@("`@("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0H@("`@*2!["B`@("`@("`@;F5X="!U;FQE<W,@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@
M("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H
M97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PH@
M("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@
M("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U
M<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@
M("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@
M(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F:"P@+3$X+"`R
M.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@
M("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@
M("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D
M9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G
M.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*
M("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?
M=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P
M.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*
M("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@
M("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"@H@("`@("`@
M("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@
M("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*
M("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M
M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L
M87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%
M35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M
M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H
M+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R
M8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U
M;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H
M($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E('L*("`@("`@
M("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I
M.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@
M)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA
M;64I.PI]"@IS=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE
M('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O
M9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@
M("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@
M("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@
M("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@
M('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@
M/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*
M("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@
M(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%
M3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI
M<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A
M<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("([
M"@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%
M3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[
M4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S
M='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@
M("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!
M3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D
M<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H
M(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN
M(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG
M.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N
M"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<
M)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@
M<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@
M)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H
M)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I]
M.PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q-PH*7U]%
M3D1?7PH``1L#.P```1`````A__]-_````23__TY@```!2/__3Y````%L__]0
MT````9#__U$$```!M/__5*@```'8__]5-````?S__U9P```"(/__5I0```)$
M__]9S````G#__UI0```"E/__7#@```*X__]>(````MS__U[````#`/__?<@`
M``,D__]^6````TC__W_L```#;/__@>0```.0__^#8````[3__X/$```#V/__
MA3````0$__^/=```!#3__Y$D```$6/__D=P```1\__^4[```!*#__Y5L```$
MQ/__F^````3H__^<<```!13__Z"8```%5/__H-P```5T__^@X```!8C__Z%8
M```%M/__H8P```74````#``````!``%\#@P/8````"`````4`$`EA````&1$
MCPF."HT+C`R+#48.R`%"#0L``````"`````X`$`EZ````3!$CPF."HT+C`R+
M#48.T"%"#0L``````"````!<`$`G&````4!$CPF."HT+C`R+#48.X`%"#0L`
M`````"````"``$`H6````#1$CPF."HT+C`R+#48.T`%"#0L``````"````"D
M`$`HC````Z1$CPF."HT+C`R+#48.^`%"#0L``````"````#(`$`L,````(Q$
MCPF."HT+C`R+#48.T`%"#0L``````"````#L`$`LO````3Q$CPF."HT+C`R+
M#48.V$%"#0L``````"````$0`$`M^````"1$CPF."HT+C`R+#48.P`%"#0L`
M`````"@```$T`$`N'````SA$CPF."HT+C`R+#8H.B0^($(<1AA)&#N`A0@T+
M````(````6``0#%4````A$2/"8X*C0N,#(L-1@[0`4(-"P``````(````80`
M0#'8```!Z$2/"8X*C0N,#(L-1@[0`4(-"P``````(````:@`0#/````!Z$2/
M"8X*C0N,#(L-1@[H`4(-"P``````(````<P`0#6H````H$2/"8X*C0N,#(L-
M1@[0`4(-"P``````(````?``0#9(```?"$2/"8X*C0N,#(L-7`ZP!$(-"P``
M````(````A0`0%50````D$2/"8X*C0N,#(L-1@[(`4(-"P``````(````C@`
M0%7@```!E$2/"8X*C0N,#(L-1@[8`4(-"P``````(````EP`0%=T```!^$2/
M"8X*C0N,#(L-1@[(`4(-"P``````(````H``0%EL```!?$2/"8X*C0N,#(L-
M1@[8`4(-"P``````(````J0`0%KH````9$2/"8X*C0N,#(L-1@[0`4(-"P``
M````*````L@`0%M,```!;$2/"8X*C0N,#(L-B@Z)#X@0AQ&&$D8.\`%"#0L`
M```L```"]`!`7+@```I$1(\)C@J-"XP,BPV*#HD/B!"'$8821@[@@P)"#0L`
M```````@```#)`!`9OP```&P1(\)C@J-"XP,BPU&#L`"0@T+```````@```#
M2`!`:*P```"X1(\)C@J-"XP,BPU&#M`!0@T+```````@```#;`!`:60```,0
M1(\)C@J-"XP,BPU&#M`!0@T+```````@```#D`!`;'0```"`1(\)C@J-"XP,
MBPU&#L@!0@T+```````@```#M`!`;/0```9T1(\)C@J-"XP,BPU&#O@!0@T+
M```````H```#V`!`<V@```"01(\)C@J-"XP,BPV*#HD/B!"'$8821@[(`4(-
M"P```"@```0$`$!S^```!"A$CPF."HT+C`R+#8H.B0^($(<1AA)&#N@!0@T+
M````$``````!>E(``7P.`1L,#V`````<````&/__FSP```!$`$2/"8X*C0N,
M#$8.P`$``````!`````X__^;8`````(`````````*````$S__YM0````>`!$
MCPF."HT+C`R+#8H.B0^($(<1AA)&#L`!```````<````>/__FYP````T`$2/
M"8X*C0N,#$8.P`$``````!P```"8__^;L````#0`1(\)C@J-"XP,1@[``0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#_____`````/____\```````````````$````!````
M`0```K(````!```"O0````$```+'`````0```P4````!```$)P````P`0!J$
M````#0!`>9`````$`$`!9&___O4`0`2T````!0!`#Y`````&`$`(@`````H`
M``7!````"P```!`````5``````````,`0.$,`````@```YP````4````!P``
M`!<`0!;H````!P!`%L0````(```#P`````D````,;____@!`%C1O____````
M`F____``0!52````````````````````````````````````````````````
M`````````````````$#@%````````````$`;#`!`&RP`0!M,`$`;;`!`&XP`
M0!NL`$`;S`!`&^P`0!P,`$`<+`!`'$P`0!QL`$`<C`!`'*P`0!S,`$`<[`!`
M'0P`0!TL`$`=3`!`'6P`0!V,`$`=K`!`'<P`0!WL`$`>#`!`'BP`0!Y,`$`>
M;`!`'HP`0!ZL`$`>S`!`'NP`0!\,`$`?+`!`'TP`0!]L`$`?C`!`'ZP`0!_,
M`$`?[`!`(`P`0"`L`$`@3`!`(&P`0"",`$`@K`!`(,P`0"#L`$`A#`!`(2P`
M0"%,`$`A;`!`(8P`0"&L`$`AS`!`(>P`0"(,`$`B+`!`(DP`0")L`$`BC`!`
M(JP`0"+,`$`B[`!`(PP`0",L`$`C3`!`(VP`0".,`$`CK`!`(\P`0"/L`$`D
M#`!`)"P`0"1,`$`D;`!`)(P`````````````````0'H"`$!Z!/____\`0'S(
M``!:MP!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,RD``$=#0SH@
M*$=.52D@-"XR+C,@*$1E8FEA;B`T+C(N,RTS*0``1T-#.B`H1&5B:6%N(#0N
M,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE87-E*0``1T-#.B`H1&5B
M:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE87-E*0``1T-#
M.B`H1&5B:6%N(#0N,RXP+3,I(#0N,RXQ(#(P,#@P-#`Q("AP<F5R96QE87-E
M*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N(#0N,BXS+3,I``!'0T,Z("A'
M3E4I(#0N,BXS("A$96)I86X@-"XR+C,M,RD``$=#0SH@*$=.52D@-"XR+C,@
M*$1E8FEA;B`T+C(N,RTS*0``1T-#.B`H1TY5*2`T+C(N,R`H1&5B:6%N(#0N
M,BXS+3,I``!'0T,Z("A$96)I86X@-"XS+C`M,RD@-"XS+C$@,C`P.#`T,#$@
M*'!R97)E;&5A<V4I``!'0T,Z("A'3E4I(#0N,BXS("A$96)I86X@-"XR+C,M
M,RD``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N
M9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````
M```````````````````````````````````````````+`````0````(`0`$T
M```!-`````T```````````````$`````````$P````<````"`$`!1````40`
M```@```````````````$`````````"4````%`````@!``60```%D```#4```
M``4`````````!`````0````A;___]@````(`0`2T```$M````\P````%````
M``````0````$````*P````L````"`$`(@```"(````<0````!@````$````$
M````$````#,````#`````@!`#Y````^0```%P0```````````````0``````
M```[;____P````(`0!52```54@```.(````%``````````(````"````2&__
M__X````"`$`6-```%C0```"0````!@````(````$`````````%<````$````
M`@!`%L0``!;$````)`````4`````````!`````P```!A````!`````(`0!;H
M```6Z````YP````%````#`````0````,````:P````$````&`$`:A```&H0`
M``!<```````````````$`````````&8````!````!@!`&N```!K@```)P```
M````````````!`````0```!Q`````0````8`0"2@```DH```5/``````````
M``````0`````````=P````$````&`$!YD```>9`````X```````````````$
M`````````'T````!`````@!`><@``'G(``!=P```````````````!```````
M``"%`````0````(`0->(``#7B````10```````````````0`````````DP``
M``$````"`$#8G```V)P```3D```````````````$`````````)T````!````
M`P!`X````.``````"```````````````!`````````"D`````0````,`0.`(
M``#@"`````@```````````````0`````````JP````$````#`$#@$```X!``
M```$```````````````$`````````+`````&`````P!`X!0``.`4````^```
M``8`````````!`````@```"Y`````0````,`0.$,``#A#````40`````````
M``````0````$````O@````$````#`$#B4```XE`````<```````````````$
M`````````,0````(`````P!`XG```.)L```0.```````````````"```````
M``#)`````0````````````#B;````<$```````````````$``````````0``
B``,`````````````Y"T```#2```````````````!````````
